@@ -16,7 +16,7 @@ AbstractModel::~AbstractModel()
 {
 }
 
-QHash<int, QByteArray> AbstractModel::roleNames() const
+QHash<int, QByteArray> AbstractModel::staticRoleNames()
 {
     QHash<int, QByteArray> roles;
     roles.insert(Qt::DisplayRole, "display");
@@ -32,6 +32,7 @@ QHash<int, QByteArray> AbstractModel::roleNames() const
     roles.insert(Kicker::UrlRole, "url");
     roles.insert(Kicker::DisabledRole, "disabled");
     roles.insert(Kicker::IsMultilineTextRole, "isMultilineText");
+    roles.insert(Kicker::DisplayWrappedRole, "displayWrapped");
 
     return roles;
 }
@@ -138,9 +139,9 @@ AbstractModel *AbstractModel::rootModel()
     return rootModel;
 }
 
-QVariantList AbstractModel::sections() const
+QAbstractListModel *AbstractModel::sections() const
 {
-    return {};
+    return nullptr;
 }
 
 void AbstractModel::entryChanged(AbstractEntry *entry)
