@@ -146,9 +146,12 @@ QVariantList createAddLauncherActionList(QObject *appletInterface, const KServic
         actionList << addToDesktopAction;
     }
 
-    if (service && ContainmentInterface::mayAddLauncher(appletInterface, ContainmentInterface::TaskManager, service->entryPath())) {
-        QVariantMap addToTaskManagerAction = Kicker::createActionItem(i18n("Pin to Task Manager"), QStringLiteral("pin"), QStringLiteral("addToTaskManager"));
-        actionList << addToTaskManagerAction;
+    if (service && ContainmentInterface::mayAddLauncher(appletInterface, ContainmentInterface::TaskManager, service)) {
+        if (!ContainmentInterface::hasLauncher(appletInterface, ContainmentInterface::TaskManager, service)) {
+            QVariantMap addToTaskManagerAction =
+                Kicker::createActionItem(i18n("Pin to Task Manager"), QStringLiteral("pin"), QStringLiteral("addToTaskManager"));
+            actionList << addToTaskManagerAction;
+        }
     } else if (ContainmentInterface::mayAddLauncher(appletInterface, ContainmentInterface::Panel)) {
         QVariantMap addToPanelAction = Kicker::createActionItem(i18n("Add to Panel (Widget)"), QStringLiteral("list-add"), QStringLiteral("addToPanel"));
         actionList << addToPanelAction;
@@ -174,7 +177,7 @@ bool handleAddLauncherAction(const QString &actionId, QObject *appletInterface,
         }
         return true;
     } else if (actionId == QLatin1String("addToTaskManager")) {
-        if (ContainmentInterface::mayAddLauncher(appletInterface, ContainmentInterface::TaskManager, service->entryPath())) {
+        if (ContainmentInterface::mayAddLauncher(appletInterface, ContainmentInterface::TaskManager, service)) {
             ContainmentInterface::addLauncher(appletInterface, ContainmentInterface::TaskManager, service->entryPath());
         }
         return true;
