@@ -35,6 +35,7 @@ namespace KAStats = KActivities::Stats;
 
 using namespace KAStats;
 using namespace KAStats::Terms;
+using namespace Qt::StringLiterals;
 
 #define AGENT_APPLICATIONS QStringLiteral("org.kde.plasma.favorites.applications")
 #define AGENT_DOCUMENTS QStringLiteral("org.kde.plasma.favorites.documents")
@@ -176,11 +177,11 @@ public:
         , m_clientId(clientId)
     {
         // Connecting the watcher
-        connect(&m_watcher, &ResultWatcher::resultLinked, [this](const QString &resource) {
+        connect(&m_watcher, &ResultWatcher::resultLinked, parent, [this](const QString &resource) {
             addResult(resource, -1);
         });
 
-        connect(&m_watcher, &ResultWatcher::resultUnlinked, [this](const QString &resource) {
+        connect(&m_watcher, &ResultWatcher::resultUnlinked, parent, [this](const QString &resource) {
             removeResult(resource);
         });
         connect(
@@ -214,8 +215,8 @@ public:
         // We want first to check whether we have an ordering for this activity.
         // If not, we will try to get a global one for this applet
 
-        const QString thisGroupName = QStringLiteral("Favorites-") + clientId + QStringLiteral("-") + m_activities.currentActivity();
-        const QString globalGroupName = QStringLiteral("Favorites-") + clientId + QStringLiteral("-global");
+        const QString thisGroupName = u"Favorites-" + clientId + u'-' + m_activities.currentActivity();
+        const QString globalGroupName = u"Favorites-" + clientId + u"-global";
 
         KConfigGroup thisCfgGroup(cfg, thisGroupName);
         KConfigGroup globalCfgGroup(cfg, globalGroupName);
@@ -260,7 +261,7 @@ public:
                         std::transform(groupOrdering.begin(), groupOrdering.end(), groupOrdering.begin(), [&](const QString &item) {
                             return normalizedId(item).value();
                         });
-                        for (auto item : m_items) {
+                        for (const auto &item : m_items) {
                             if (!groupOrdering.contains(item.value())) {
                                 continue;
                             }
@@ -328,18 +329,6 @@ public:
             return;
         }
 
-        // TODO Remove a few releases after Plasma 5.25 as this should become dead code, once users have run this code at least once
-        // Converts old-style applications favorites with path (/usrshare/applications/org.kde.dolphin.desktop) or storageId (org.kde.dolphin.desktop)
-        if ((_resource.startsWith(QLatin1String("/")) || QUrl(_resource).scheme().isEmpty()) && _resource.endsWith(QLatin1String(".desktop"))) {
-            m_watcher.unlinkFromActivity(QUrl(_resource), QStringLiteral(":any"), agentForUrl(resource));
-
-            const auto normalized = normalizedId(resource).value();
-            qCDebug(KICKER_DEBUG) << "Converting old-style application favorite entry" << _resource << "to" << normalized;
-
-            m_watcher.linkToActivity(QUrl(normalized), QStringLiteral(":any"), agentForUrl(resource));
-            return;
-        }
-
         if (index == -1) {
             index = m_items.count();
         }
@@ -498,7 +487,7 @@ public:
         qCDebug(KICKER_DEBUG) << "Saving ordering for" << currentActivity << "and global" << ids;
 
         for (const auto &activity : activities) {
-            const QString groupName = QStringLiteral("Favorites-") + clientId + QStringLiteral("-") + activity;
+            const QString groupName = u"Favorites-" + clientId + u'-' + activity;
 
             KConfigGroup cfgGroup(cfg, groupName);
 
@@ -603,23 +592,31 @@ bool KAStatsFavoritesModel::isFavorite(const QString &id) const
     return d && d->m_itemEntries.contains(id);
 }
 
-#if BUILD_TESTING
 void KAStatsFavoritesModel::portOldFavorites(const QStringList &_ids)
-#else
-void KAStatsFavoritesModel::portOldFavorites(const QStringList &ids)
-#endif
 {
     if (!d)
         return;
 
+    KConfig config(u"kicker-extra-favoritesrc"_s);
+    auto group = config.group(u"General"_s);
+    auto prepend = group.readXdgListEntry("Prepend", QStringList());
+    auto append = group.readXdgListEntry("Append", QStringList());
+    auto ignoreDefaults = group.readEntry("IgnoreDefaults", false);
+
 #if BUILD_TESTING
-    const QStringList ids = qEnvironmentVariableIsSet("KDECI_BUILD") ? QStringList{
-        QLatin1String("org.kde.plasma.emojier.desktop"),
-        QLatin1String("linguist5.desktop"),
-        QLatin1String("org.qt.linguist6.desktop"),
-    } : _ids;
+    if (qEnvironmentVariableIsSet("KDECI_BUILD")) {
+        prepend = QStringList{
+            QLatin1String("org.kde.plasma.emojier.desktop"),
+            QLatin1String("linguist5.desktop"),
+            QLatin1String("org.qt.linguist6.desktop"),
+        };
+        ignoreDefaults = true;
+        append.clear();
+    }
 #endif
 
+    const auto ids = prepend + (ignoreDefaults ? QStringList() : _ids) + append;
+
     qCDebug(KICKER_DEBUG) << "portOldFavorites" << ids;
 
     const QString activityId = QStringLiteral(":global");
