@@ -29,7 +29,7 @@ public:
     QQuickItem *internalSystray();
 
 protected:
-    void constraintsEvent(Plasma::Types::Constraints constraints) override;
+    void constraintsEvent(Plasma::Applet::Constraints constraints) override;
     void ensureSystrayExists();
 
 Q_SIGNALS:
