@@ -22,7 +22,7 @@ public:
     explicit DaysModelPrivate();
 
     QList<DayData> *data = nullptr;
-    QList<QObject *> qmlData;
+    QVariantList /*QList<EventDataDecorator>*/ qmlData;
     QMultiHash<QDate, CalendarEvents::EventData> eventsData;
     QHash<QDate /* Gregorian */, QCalendar::YearMonthDay> alternateDatesData;
     QHash<QDate, CalendarEvents::CalendarEventsPlugin::SubLabel> subLabelsData;
@@ -102,7 +102,7 @@ QVariant DaysModel::data(const QModelIndex &index, int role) const
         case Events:
             return QVariant::fromValue(d->eventsData.values(currentDate));
         case EventCount:
-            return d->eventsData.values(currentDate).count();
+            return d->eventsData.count(currentDate);
         case containsMajorEventItems:
             return hasMajorEventAtDate(currentDate);
         case containsMinorEventItems:
@@ -119,7 +119,7 @@ QVariant DaysModel::data(const QModelIndex &index, int role) const
             break;
         }
 
-        if (d->alternateDatesData.count(currentDate)) {
+        if (d->alternateDatesData.contains(currentDate)) {
             switch (role) {
             case AlternateYearNumber:
                 return d->alternateDatesData.value(currentDate).year;
@@ -132,7 +132,7 @@ QVariant DaysModel::data(const QModelIndex &index, int role) const
             }
         }
 
-        if (d->subLabelsData.count(currentDate)) {
+        if (d->subLabelsData.contains(currentDate)) {
             switch (role) {
             case SubLabel:
                 return d->subLabelsData.value(currentDate).label;
@@ -345,14 +345,13 @@ void DaysModel::onSubLabelReady(const QHash<QDate, CalendarEvents::CalendarEvent
     Q_EMIT dataChanged(index(0, 0), index(d->data->count() - 1, 0), {SubLabel, SubYearLabel, SubMonthLabel, SubDayLabel});
 }
 
-QList<QObject *> DaysModel::eventsForDate(const QDate &date)
+QVariantList DaysModel::eventsForDate(const QDate &date)
 {
     if (d->lastRequestedAgendaDate == date && !d->agendaNeedsUpdate) {
         return d->qmlData;
     }
 
     d->lastRequestedAgendaDate = date;
-    qDeleteAll(d->qmlData);
     d->qmlData.clear();
 
     QList<CalendarEvents::EventData> events = d->eventsData.values(date);
@@ -364,7 +363,7 @@ QList<QObject *> DaysModel::eventsForDate(const QDate &date)
     });
 
     for (const CalendarEvents::EventData &event : std::as_const(events)) {
-        d->qmlData << new EventDataDecorator(event, this);
+        d->qmlData.append(QVariant::fromValue(EventDataDecorator(event)));
     }
 
     d->agendaNeedsUpdate = false;
@@ -409,27 +408,28 @@ bool DaysModel::hasMinorEventAtDate(const QDate &date) const
     return false;
 }
 
-void DaysModel::setPluginsManager(QObject *manager)
+void DaysModel::setPluginsManager(EventPluginsManager *manager)
 {
     if (d->pluginsManager) {
-        disconnect(d->pluginsManager, nullptr, this, nullptr);
+        disconnect(d->pluginsManager, &EventPluginsManager::dataReady, this, &DaysModel::onDataReady);
+        disconnect(d->pluginsManager, &EventPluginsManager::eventModified, this, &DaysModel::onEventModified);
+        disconnect(d->pluginsManager, &EventPluginsManager::eventRemoved, this, &DaysModel::onEventRemoved);
+        disconnect(d->pluginsManager, &EventPluginsManager::alternateCalendarDateReady, this, &DaysModel::onAlternateCalendarDateReady);
+        disconnect(d->pluginsManager, &EventPluginsManager::subLabelReady, this, &DaysModel::onSubLabelReady);
+        disconnect(d->pluginsManager, &EventPluginsManager::pluginsChanged, this, &DaysModel::update);
     }
 
-    EventPluginsManager *m = qobject_cast<EventPluginsManager *>(manager);
+    d->pluginsManager = manager;
 
-    if (!m) {
-        return;
+    if (d->pluginsManager) {
+        connect(d->pluginsManager, &EventPluginsManager::dataReady, this, &DaysModel::onDataReady);
+        connect(d->pluginsManager, &EventPluginsManager::eventModified, this, &DaysModel::onEventModified);
+        connect(d->pluginsManager, &EventPluginsManager::eventRemoved, this, &DaysModel::onEventRemoved);
+        connect(d->pluginsManager, &EventPluginsManager::alternateCalendarDateReady, this, &DaysModel::onAlternateCalendarDateReady);
+        connect(d->pluginsManager, &EventPluginsManager::subLabelReady, this, &DaysModel::onSubLabelReady);
+        connect(d->pluginsManager, &EventPluginsManager::pluginsChanged, this, &DaysModel::update);
     }
 
-    d->pluginsManager = m;
-
-    connect(d->pluginsManager, &EventPluginsManager::dataReady, this, &DaysModel::onDataReady);
-    connect(d->pluginsManager, &EventPluginsManager::eventModified, this, &DaysModel::onEventModified);
-    connect(d->pluginsManager, &EventPluginsManager::eventRemoved, this, &DaysModel::onEventRemoved);
-    connect(d->pluginsManager, &EventPluginsManager::alternateCalendarDateReady, this, &DaysModel::onAlternateCalendarDateReady);
-    connect(d->pluginsManager, &EventPluginsManager::subLabelReady, this, &DaysModel::onSubLabelReady);
-    connect(d->pluginsManager, &EventPluginsManager::pluginsChanged, this, &DaysModel::update);
-
     QMetaObject::invokeMethod(this, "update", Qt::QueuedConnection);
 }
 
