@@ -31,6 +31,7 @@ class ItemContainer;
 class AppletsLayout : public QQuickItem
 {
     Q_OBJECT
+    QML_ELEMENT
     Q_INTERFACES(QQmlParserStatus)
 
     Q_PROPERTY(QString configKey READ configKey WRITE setConfigKey NOTIFY configKeyChanged)
@@ -197,9 +198,10 @@ protected:
     // void classBegin() override;
     void componentComplete() override;
     void mousePressEvent(QMouseEvent *event) override;
-    void mouseMoveEvent(QMouseEvent *event) override;
     void mouseReleaseEvent(QMouseEvent *event) override;
-    void mouseUngrabEvent() override;
+
+    void touchEvent(QTouchEvent *event) override;
+    void touchUngrabEvent() override;
 
 private Q_SLOTS:
     void appletAdded(Plasma::Applet *applet);
@@ -208,6 +210,9 @@ private Q_SLOTS:
 private:
     AppletContainer *createContainerForApplet(PlasmaQuick::AppletQuickItem *appletItem);
 
+    void handleMoveEvent(const QPointF &scenePosition);
+    void handleReleaseEvent(const QPointF &scenePosition);
+
     QString m_configKey;
     QString m_fallbackConfigKey;
     QTimer *m_saveLayoutTimer;
@@ -236,8 +241,8 @@ private:
     QSizeF m_savedSize;
     QRectF m_geometryBeforeResolutionChange;
 
-    QPointF m_mouseDownPosition = QPoint(-1, -1);
-    bool m_mouseDownWasEditMode = false;
+    QPointF m_touchDownPosition = QPoint(-1, -1);
+    bool m_touchDownWasEditMode = false;
     bool m_editMode = false;
     bool m_relayoutLock = false;
 };
