@@ -8,7 +8,7 @@
 
 #include "ion_envcan.h"
 
-// #include "ion_envcandebug.h"
+#include "ion_envcandebug.h"
 
 #include <KIO/TransferJob>
 #include <KLocalizedString>
@@ -444,7 +444,7 @@ QStringList EnvCanadaIon::validate(const QString &source) const
     QHash<QString, EnvCanadaIon::XMLMapInfo>::const_iterator it = m_places.constBegin();
     while (it != m_places.constEnd()) {
         if (it.key().toUpper().contains(sourceNormalized)) {
-            placeList.append(QStringLiteral("place|") + it.key());
+            placeList.append(u"place|" + it.key());
         }
         ++it;
     }
@@ -456,8 +456,6 @@ QStringList EnvCanadaIon::validate(const QString &source) const
 // Get a specific Ion's data
 bool EnvCanadaIon::updateIonSource(const QString &source)
 {
-    // qCDebug(IONENGINE_ENVCAN) << "updateIonSource()" << source;
-
     // We expect the applet to send the source in the following tokenization:
     // ionname|validate|place_name - Triggers validation of place
     // ionname|weather|place_name - Triggers receiving weather of place
@@ -473,9 +471,9 @@ bool EnvCanadaIon::updateIonSource(const QString &source)
     if (sourceAction[1] == QLatin1String("validate") && sourceAction.size() > 2) {
         const QStringList result = validate(sourceAction[2]);
 
-        const QString reply = (result.size() == 1        ? QString(QStringLiteral("envcan|valid|single|") + result[0])
-                                   : (result.size() > 1) ? QString(QStringLiteral("envcan|valid|multiple|") + result.join(QLatin1Char('|')))
-                                                         : QString(QStringLiteral("envcan|invalid|single|") + sourceAction[2]));
+        const QString reply = (result.size() == 1        ? QString(u"envcan|valid|single|" + result[0])
+                                   : (result.size() > 1) ? QString(u"envcan|valid|multiple|" + result.join(QLatin1Char('|')))
+                                                         : QString(u"envcan|invalid|single|" + sourceAction[2]));
         setData(source, QStringLiteral("validate"), reply);
 
         return true;
@@ -491,11 +489,9 @@ bool EnvCanadaIon::updateIonSource(const QString &source)
 // Parses city list and gets the correct city based on ID number
 void EnvCanadaIon::getXMLSetup()
 {
-    // qCDebug(IONENGINE_ENVCAN) << "getXMLSetup()";
-
     // If network is down, we need to spin and wait
-
-    const QUrl url(QStringLiteral("http://dd.weather.gc.ca/citypage_weather/xml/siteList.xml"));
+    const QUrl url(QStringLiteral("https://dd.weather.gc.ca/citypage_weather/xml/siteList.xml"));
+    qCDebug(IONENGINE_ENVCAN) << "Fetching station list:" << url;
 
     KIO::TransferJob *getJob = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
 
@@ -514,17 +510,13 @@ void EnvCanadaIon::getXMLData(const QString &source)
         }
     }
 
-    // qCDebug(IONENGINE_ENVCAN) << source;
-
     // Demunge source name for key only.
     QString dataKey = source;
     dataKey.remove(QStringLiteral("envcan|weather|"));
     const XMLMapInfo &place = m_places[dataKey];
 
-    const QUrl url(QLatin1String("http://dd.weather.gc.ca/citypage_weather/xml/") + place.territoryName + QLatin1Char('/') + place.cityCode
-                   + QStringLiteral("_e.xml"));
-    // url="file:///home/spstarr/Desktop/s0000649_e.xml";
-    // qCDebug(IONENGINE_ENVCAN) << "Will Try URL: " << url;
+    const QUrl url(QStringLiteral("https://dd.weather.gc.ca/citypage_weather/xml/%1/%2_e.xml").arg(place.territoryName, place.cityCode));
+    qCDebug(IONENGINE_ENVCAN) << "Fetching weather URL:" << url;
 
     if (place.territoryName.isEmpty() && place.cityCode.isEmpty()) {
         setData(source, QStringLiteral("validate"), QStringLiteral("envcan|malformed"));
@@ -545,12 +537,10 @@ void EnvCanadaIon::setup_slotDataArrived(KIO::Job *job, const QByteArray &data)
     Q_UNUSED(job)
 
     if (data.isEmpty()) {
-        // qCDebug(IONENGINE_ENVCAN) << "done!";
         return;
     }
 
     // Send to xml.
-    // qCDebug(IONENGINE_ENVCAN) << data;
     m_xmlSetup.addData(data);
 }
 
@@ -568,7 +558,6 @@ void EnvCanadaIon::slotJobFinished(KJob *job)
 {
     // Dual use method, if we're fetching location data to parse we need to do this first
     const QString source = m_jobList.value(job);
-    // qCDebug(IONENGINE_ENVCAN) << source << m_sourcesToReset.contains(source);
     setData(source, Data());
     QXmlStreamReader *reader = m_jobXml.value(job);
     if (reader) {
@@ -595,7 +584,6 @@ void EnvCanadaIon::setup_slotJobFinished(KJob *job)
     Q_UNUSED(job)
     const bool success = readXMLSetup();
     m_xmlSetup.clear();
-    // qCDebug(IONENGINE_ENVCAN) << success << m_sourcesToReset;
     setInitialized(success);
 }
 
@@ -607,8 +595,6 @@ bool EnvCanadaIon::readXMLSetup()
     QString code;
     QString cityName;
 
-    // qCDebug(IONENGINE_ENVCAN) << "readXMLSetup()";
-
     while (!m_xmlSetup.atEnd()) {
         m_xmlSetup.readNext();
 
@@ -631,7 +617,7 @@ bool EnvCanadaIon::readXMLSetup()
 
         if (m_xmlSetup.isEndElement() && elementName == QLatin1String("site")) {
             EnvCanadaIon::XMLMapInfo info;
-            QString tmp = cityName + QStringLiteral(", ") + territory; // Build the key name.
+            QString tmp = cityName + u", " + territory; // Build the key name.
 
             // Set the mappings
             info.cityCode = code;
@@ -687,8 +673,6 @@ bool EnvCanadaIon::readXMLData(const QString &source, QXmlStreamReader &xml)
 {
     WeatherData data;
 
-    // qCDebug(IONENGINE_ENVCAN) << "readXMLData()";
-
     QString dataKey = source;
     dataKey.remove(QStringLiteral("envcan|weather|"));
     data.shortTerritoryName = m_places[dataKey].territoryName;
@@ -1376,14 +1360,12 @@ void EnvCanadaIon::parseUnknownElement(QXmlStreamReader &xml) const
 
 void EnvCanadaIon::updateWeather(const QString &source)
 {
-    // qCDebug(IONENGINE_ENVCAN) << "updateWeather()";
-
     const WeatherData &weatherData = m_weatherData[source];
 
     Plasma5Support::DataEngine::Data data;
 
     data.insert(QStringLiteral("Country"), weatherData.countryName);
-    data.insert(QStringLiteral("Place"), QVariant(weatherData.cityName + QStringLiteral(", ") + weatherData.shortTerritoryName));
+    data.insert(QStringLiteral("Place"), QVariant(QString(weatherData.cityName + u", " + weatherData.shortTerritoryName)));
     data.insert(QStringLiteral("Region"), weatherData.regionName);
 
     data.insert(QStringLiteral("Station"), weatherData.stationID.isEmpty() ? i18n("N/A") : weatherData.stationID.toUpper());
@@ -1405,7 +1387,6 @@ void EnvCanadaIon::updateWeather(const QString &source)
     if (!weatherData.condition.isEmpty()) {
         data.insert(QStringLiteral("Current Conditions"), i18nc("weather condition", weatherData.condition.toUtf8().data()));
     }
-    // qCDebug(IONENGINE_ENVCAN) << "i18n condition string: " << qPrintable(condition(source));
 
     QMap<QString, ConditionIcons> conditionList = conditionIcons();
 
@@ -1496,10 +1477,10 @@ void EnvCanadaIon::updateWeather(const QString &source)
         const WeatherData::WeatherEvent *warning = warnings.at(k);
         const QString number = QString::number(k);
 
-        data.insert(QStringLiteral("Warning Priority ") + number, warning->priority);
-        data.insert(QStringLiteral("Warning Description ") + number, warning->description);
-        data.insert(QStringLiteral("Warning Info ") + number, warning->url);
-        data.insert(QStringLiteral("Warning Timestamp ") + number, warning->timestamp);
+        data.insert(u"Warning Priority " + number, warning->priority);
+        data.insert(u"Warning Description " + number, warning->description);
+        data.insert(u"Warning Info " + number, warning->url);
+        data.insert(u"Warning Timestamp " + number, warning->timestamp);
     }
 
     const QList<WeatherData::ForecastInfo *> &forecasts = weatherData.forecasts;
@@ -1510,6 +1491,11 @@ void EnvCanadaIon::updateWeather(const QString &source)
     int i = 0;
     for (const WeatherData::ForecastInfo *forecastInfo : forecasts) {
         QString forecastPeriod = forecastInfo->forecastPeriod;
+        // Indicate whether the first forcast is a nightly one
+        if (i == 0) {
+            data.insert(QStringLiteral("Forecast Starts at Night"), forecastPeriod.contains(QStringLiteral("night")));
+        }
+
         if (forecastPeriod.isEmpty()) {
             forecastPeriod = i18n("N/A");
         } else {
@@ -1576,7 +1562,11 @@ void EnvCanadaIon::updateWeather(const QString &source)
 
     data.insert(QStringLiteral("Credit"), i18nc("credit line, keep string short", "Data from Environment and Climate Change\302\240Canada"));
     data.insert(QStringLiteral("Credit Url"), weatherData.creditUrl);
+
+    Q_EMIT cleanUpData(source);
     setData(source, data);
+
+    qCDebug(IONENGINE_ENVCAN) << "Updated weather:" << source << data;
 }
 
 void EnvCanadaIon::dataUpdated(const QString &sourceName, const Plasma5Support::DataEngine::Data &data)
