@@ -258,7 +258,7 @@ void InteractiveConsole::loadScript(const QString &script)
     } else {
         QFile file(KShell::tildeExpand(script));
         if (file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-            m_editor->setText(file.readAll());
+            m_editor->setText(QString::fromLocal8Bit(file.readAll()));
             return;
         }
     }
@@ -413,7 +413,7 @@ void InteractiveConsole::scriptFileDataRecvd(KIO::Job *job, const QByteArray &da
     Q_ASSERT(m_editor);
 
     if (job == m_job.data()) {
-        m_editor->insertPlainText(data);
+        m_editor->insertPlainText(QString::fromLocal8Bit(data));
     }
 }
 
@@ -555,10 +555,10 @@ void InteractiveConsole::evaluateScript()
         } else {
             const int id = reply.arguments().constFirst().toInt();
             QDBusConnection::sessionBus()
-                .connect(s_kwinService, "/Scripting/Script"_L1 + QString::number(id), QString(), QStringLiteral("print"), this, SLOT(print(QString)));
+                .connect(s_kwinService, u"/Scripting/Script" + QString::number(id), QString(), QStringLiteral("print"), this, SLOT(print(QString)));
             QDBusConnection::sessionBus()
-                .connect(s_kwinService, "/" + QString::number(id), QString(), QStringLiteral("printError"), this, SLOT(print(QString)));
-            message = QDBusMessage::createMethodCall(s_kwinService, "/Scripting/Script"_L1 + QString::number(id), QString(), QStringLiteral("run"));
+                .connect(s_kwinService, u'/' + QString::number(id), QString(), QStringLiteral("printError"), this, SLOT(print(QString)));
+            message = QDBusMessage::createMethodCall(s_kwinService, u"/Scripting/Script" + QString::number(id), QString(), QStringLiteral("run"));
             reply = QDBusConnection::sessionBus().call(message);
             if (reply.type() == QDBusMessage::ErrorMessage) {
                 print(reply.errorMessage());
