@@ -172,7 +172,7 @@ void KCMDesktopTheme::applyPlasmaTheme(QQuickItem *item, const QString &themeNam
         m_themes[themeName] = imageSet;
     }
 
-    Q_FOREACH (KSvg::Svg *svg, item->findChildren<KSvg::Svg *>()) {
+    for (const auto children = item->findChildren<KSvg::Svg *>(); KSvg::Svg * svg : children) {
         auto *frame = qobject_cast<KSvg::FrameSvg *>(svg);
         svg->setUsingRenderingCache(false);
         if (frame) {
