@@ -31,6 +31,7 @@
 #include "optionsmodel.h"
 #include "regionandlangsettings.h"
 
+using namespace Qt::StringLiterals;
 using namespace KCM_RegionAndLang;
 
 K_PLUGIN_CLASS_WITH_JSON(KCMRegionAndLang, "kcm_regionandlang.json")
@@ -84,7 +85,12 @@ KCMRegionAndLang::KCMRegionAndLang(QObject *parent, const KPluginMetaData &data)
     qmlRegisterType<LanguageListModel>("kcmregionandlang", 1, 0, "LanguageListModel");
     qmlRegisterType<BinaryDialectModel>("kcmregionandlang", 1, 0, "BinaryDialectModel");
     qRegisterMetaType<KCM_RegionAndLang::SettingType>();
-    qmlRegisterUncreatableMetaObject(KCM_RegionAndLang::staticMetaObject, "kcmregionandlang", 1, 0, "SettingType", "Error: SettingType is an enum");
+    qmlRegisterUncreatableMetaObject(KCM_RegionAndLang::staticMetaObject,
+                                     "kcmregionandlang",
+                                     1,
+                                     0,
+                                     "SettingType",
+                                     QStringLiteral("Error: SettingType is an enum"));
 
     // fedora pre generate locales, fetch available locales from localectl. /usr/share/i18n/locales is empty in fedora
     QDir glibcLocaleDir(localeFileDirPath());
@@ -93,7 +99,7 @@ KCMRegionAndLang::KCMRegionAndLang(QObject *parent, const KPluginMetaData &data)
         if (!localectlPath.isEmpty()) {
             m_localectl = new QProcess(this);
             m_localectl->setProgram(localectlPath);
-            m_localectl->setArguments({QStringLiteral("list-locales")});
+            m_localectl->setArguments({QStringLiteral("list-locales"), QStringLiteral("--no-pager")});
             connect(m_localectl, &QProcess::finished, this, [this](int exitCode, QProcess::ExitStatus status) {
                 m_enabled = true; // set to true even if failed. otherwise our failed notification is also grey out
                 if (exitCode != 0 || status != QProcess::NormalExit) {
@@ -211,7 +217,7 @@ void KCMRegionAndLang::save()
 void KCMRegionAndLang::load()
 {
     KQuickManagedConfigModule::load();
-    engine()->addImageProvider("flags", new FlagImageProvider);
+    engine()->addImageProvider(u"flags"_s, new FlagImageProvider);
 
     m_settings->load();
     m_optionsModel->load();
@@ -348,7 +354,7 @@ std::unordered_map<QString, QString> KCMRegionAndLang::constructGlibcLocaleMap()
     // not glibc system or corrupted system
     if (availableLocales.isEmpty()) {
         if (m_localectl) {
-            availableLocales = QString(m_localectl->readAllStandardOutput()).split('\n');
+            availableLocales = QString::fromLocal8Bit(m_localectl->readAllStandardOutput()).split(u'\n');
         }
         if (availableLocales.isEmpty()) {
             Q_EMIT encountedError(failedFindLocalesMessage());
@@ -360,7 +366,7 @@ std::unordered_map<QString, QString> KCMRegionAndLang::constructGlibcLocaleMap()
     std::unordered_map<QString, std::vector<QString>> baseLocaleMap(availableLocales.size());
     for (const auto &glibcLocale : availableLocales) {
         // we want only absolute base locale code, for sr@ijekavian and en_US, we get sr and en
-        auto baseLocale = glibcLocale.split('_')[0].split('@')[0];
+        auto baseLocale = glibcLocale.split(u'_')[0].split(u'@')[0];
         if (baseLocaleMap.contains(baseLocale)) {
             baseLocaleMap[baseLocale].push_back(glibcLocale);
         } else {
@@ -379,7 +385,7 @@ std::unordered_map<QString, QString> KCMRegionAndLang::constructGlibcLocaleMap()
 
     auto plasmaLocales = KLocalizedString::availableDomainTranslations(QByteArrayLiteral("plasmashell")).values();
     for (const auto &plasmaLocale : plasmaLocales) {
-        auto baseLocale = plasmaLocale.split('_')[0].split('@')[0];
+        auto baseLocale = plasmaLocale.split(u'_')[0].split(u'@')[0];
         if (baseLocaleMap.contains(baseLocale)) {
             const auto &prefixedLocales = baseLocaleMap[baseLocale];
 
@@ -391,7 +397,7 @@ std::unordered_map<QString, QString> KCMRegionAndLang::constructGlibcLocaleMap()
             }
 
             // language name with same country code has higher priority, eg. es_ES > es_PA, de_DE > de_DE@euro
-            auto mainLocale = plasmaLocale + "_" + plasmaLocale.toUpper();
+            auto mainLocale = plasmaLocale + u'_' + plasmaLocale.toUpper();
             fullMatch = std::find(prefixedLocales.begin(), prefixedLocales.end(), mainLocale);
             if (fullMatch != prefixedLocales.end()) {
                 addToMap(plasmaLocale, *fullMatch);
