@@ -105,8 +105,8 @@ bool LanguageListModel::isSupportedLanguage(const QString &language) const
 
     // If the language string passed has a territory attached (like fr_FR) then chop it off,
     // and try searching for just the language.
-    if (language.contains('_')) {
-        const QString languageName{language.left(language.indexOf('_'))};
+    if (language.contains(u'_')) {
+        const QString languageName{language.left(language.indexOf(u'_'))};
         return m_availableLanguages.contains(languageName);
     }
 
@@ -394,7 +394,9 @@ void SelectedLanguageModel::saveLanguages()
                 m_settings->setLang(glibcLang.value());
             }
 #else
-            m_settings->setLang(m_selectedLanguages.front());
+            auto selectedLocale = QLocale(m_selectedLanguages.front());
+            auto utf8Lang = KCMRegionAndLang::toUTF8Locale(selectedLocale.name());
+            m_settings->setLang(utf8Lang);
 #endif
         }
         QString languages;
