@@ -37,6 +37,8 @@ K_PLUGIN_CLASS_WITH_JSON(WallpaperModule, "kcm_wallpaper.json")
 
 Q_DECLARE_METATYPE(QColor)
 
+using namespace Qt::StringLiterals;
+
 QDBusArgument &operator<<(QDBusArgument &argument, const QColor &color)
 {
     argument.beginStructure();
@@ -57,7 +59,7 @@ const QDBusArgument &operator>>(const QDBusArgument &argument, QColor &color)
 
 WallpaperModule::WallpaperModule(QObject *parent, const KPluginMetaData &data)
     : KQuickConfigModule(parent, data)
-    , m_config(KSharedConfig::openConfig(QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + "/plasma-org.kde.plasma.desktop-appletsrc",
+    , m_config(KSharedConfig::openConfig(QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + u"/plasma-org.kde.plasma.desktop-appletsrc",
                                          KConfig::OpenFlag::SimpleConfig))
     , m_activityConsumer(new KActivities::Consumer(this))
 {
@@ -155,7 +157,7 @@ void WallpaperModule::onScreenChanged()
             break;
         }
     }
-    Q_ASSERT(m_containmentIdx != "");
+    Q_ASSERT(!m_containmentIdx.isEmpty());
 
     auto containmentConfigGroup = containmentsGroup.group(m_containmentIdx);
     m_loadedWallpaperplugin = containmentConfigGroup.readEntry("wallpaperplugin");
@@ -303,7 +305,7 @@ void WallpaperModule::load()
 void WallpaperModule::save()
 {
     KQuickConfigModule::save();
-    auto iface = new QDBusInterface("org.kde.plasmashell", "/PlasmaShell", "org.kde.PlasmaShell", QDBusConnection::sessionBus(), this);
+    auto iface = new QDBusInterface(u"org.kde.plasmashell"_s, u"/PlasmaShell"_s, u"org.kde.PlasmaShell"_s, QDBusConnection::sessionBus(), this);
     if (!iface->isValid()) {
         qCWarning(KCM_WALLPAPER_DEBUG) << qPrintable(QDBusConnection::sessionBus().lastError().message());
         return;
