@@ -5,13 +5,15 @@
 */
 
 #include "../klipper.h"
-#include "../history.h"
+#include "../historycycler.h"
 #include "../historyitem.h"
 #include "../historymodel.h"
 
 #include <KConfigGroup>
 #include <KSharedConfig>
+#include <KSystemClipboard>
 
+#include <QMimeData>
 #include <QScopeGuard>
 #include <QTest>
 
@@ -50,8 +52,7 @@ void KlipperTest::initTestCase()
 
 void KlipperTest::testBug465225()
 {
-    const QString folderPath =
-        QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QDir::separator() + QStringLiteral("klipper") + QDir::separator();
+    const QString folderPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QDir::separator() + u"klipper" + QDir::separator();
     QVERIFY(QDir().mkpath(folderPath));
     QVERIFY(QFile(QFINDTESTDATA("./data/bug465225.lst")).copy(QDir(folderPath).absoluteFilePath(QStringLiteral("history2.lst"))));
 
@@ -68,33 +69,36 @@ void KlipperTest::testBug465225()
     config.writeEntry("MaxClipItems", 30);
     QVERIFY(config.sync());
 
+    auto clipboard = KSystemClipboard::instance();
     // Load the history file which contains faulty image data
     {
+        clipboard->clear(QClipboard::Clipboard); // Reset local clipboard
         auto klipper = std::make_unique<Klipper>(this, klipperConfig);
-        QCOMPARE(klipper->history()->model()->rowCount(), 1);
-        QCOMPARE(klipper->history()->first()->type(), HistoryItemType::Image);
+        QCOMPARE(HistoryModel::self()->rowCount(), 1);
+        QCOMPARE(HistoryModel::self()->first()->type(), HistoryItemType::Image);
 
-        auto mimeData = klipper->history()->first()->mimeData();
+        auto mimeData = HistoryModel::self()->first()->mimeData();
 
-        QClipboard *clipboard = qGuiApp->clipboard();
-        clipboard->setText(QDateTime::currentDateTime().toString());
+        QMimeData *data = new QMimeData;
+        data->setText(QDateTime::currentDateTime().toString());
+        clipboard->setMimeData(data, QClipboard::Clipboard);
         QCoreApplication::processEvents();
-        QCOMPARE(klipper->history()->model()->rowCount(), 2);
+        QTRY_COMPARE(HistoryModel::self()->rowCount(), 2);
 
-        clipboard->setMimeData(mimeData);
+        clipboard->setMimeData(mimeData, QClipboard::Clipboard);
         QCoreApplication::processEvents();
-        QCOMPARE(klipper->history()->model()->rowCount(), 2);
-        QCOMPARE(klipper->history()->first()->type(), HistoryItemType::Image);
+        QCOMPARE(HistoryModel::self()->rowCount(), 2);
+        QCOMPARE(HistoryModel::self()->first()->type(), HistoryItemType::Image);
 
         klipper->saveClipboardHistory();
     }
 
     // Now load the history file again
     {
+        clipboard->clear(QClipboard::Clipboard); // Reset local clipboard
         auto klipper = std::make_unique<Klipper>(this, klipperConfig);
-        QCOMPARE(klipper->history()->model()->rowCount(), 2);
-        QCOMPARE(klipper->history()->first()->type(), HistoryItemType::Image);
-        QVERIFY(klipper->history()->first()->uuid() != klipper->history()->first()->next_uuid());
+        QCOMPARE(HistoryModel::self()->rowCount(), 2);
+        QCOMPARE(HistoryModel::self()->first()->type(), HistoryItemType::Image);
     }
 }
 
