@@ -10,9 +10,6 @@
 
 #include "klipper.h"
 
-#include <chrono>
-#include <zlib.h>
-
 #include "klipper_debug.h"
 #include <QApplication>
 #include <QBoxLayout>
@@ -24,8 +21,6 @@
 #include <QMessageBox>
 #include <QPushButton>
 #include <QResizeEvent>
-#include <QSaveFile>
-#include <QtConcurrentRun>
 
 #include <KAboutData>
 #include <KActionCollection>
@@ -43,7 +38,7 @@
 
 #include "../c_ptr.h"
 #include "configdialog.h"
-#include "history.h"
+#include "historycycler.h"
 #include "historyitem.h"
 #include "historymodel.h"
 #include "historystringitem.h"
@@ -59,15 +54,24 @@
 #include <xcb/xcb.h>
 #endif
 
-using namespace std::chrono_literals;
+std::shared_ptr<Klipper> Klipper::self()
+{
+    static std::weak_ptr<Klipper> s_instance;
+    if (s_instance.expired()) {
+        std::shared_ptr<Klipper> ptr = std::make_shared<Klipper>(nullptr, KSharedConfig::openConfig(QStringLiteral("klipperrc")));
+        s_instance = ptr;
+        return ptr;
+    }
+    return s_instance.lock();
+}
 
 // config == KGlobal::config for process, otherwise applet
 Klipper::Klipper(QObject *parent, const KSharedConfigPtr &config)
     : QObject(parent)
     , m_clip(SystemClipboard::self())
+    , m_historyCycler(new HistoryCycler(this))
     , m_quitAction(nullptr)
     , m_config(config)
-    , m_saveFileTimer(nullptr)
     , m_plasmashell(nullptr)
 {
     QDBusConnection::sessionBus().registerService(QStringLiteral("org.kde.klipper"));
@@ -78,13 +82,10 @@ Klipper::Klipper(QObject *parent, const KSharedConfigPtr &config)
     connect(m_clip.get(), &SystemClipboard::ignored, this, &Klipper::slotIgnored);
     connect(m_clip.get(), &SystemClipboard::newClipData, this, &Klipper::checkClipData);
 
-    m_history = new History(this);
-    m_popup = new KlipperPopup(m_history);
-    m_popup->setWindowFlags(m_popup->windowFlags() | Qt::FramelessWindowHint);
-    connect(m_history, &History::changed, this, &Klipper::slotHistoryChanged);
-    connect(m_history, &History::changed, m_popup, &KlipperPopup::slotHistoryChanged);
-    connect(m_history, &History::topIsUserSelectedSet, m_popup, &KlipperPopup::slotTopIsUserSelectedSet);
-    connect(m_history, &History::changed, this, &Klipper::clipboardHistoryUpdated);
+    m_historyModel = HistoryModel::self();
+    m_popup = std::make_unique<KlipperPopup>();
+    connect(m_historyModel.get(), &HistoryModel::changed, this, &Klipper::slotHistoryChanged);
+    connect(m_historyModel.get(), &HistoryModel::changed, this, &Klipper::clipboardHistoryUpdated);
 
     // we need that collection, otherwise KToggleAction is not happy :}
     m_collection = new KActionCollection(this);
@@ -98,38 +99,21 @@ Klipper::Klipper(QObject *parent, const KSharedConfigPtr &config)
     /*
      * Create URL grabber
      */
-    m_myURLGrabber = new URLGrabber(m_history);
+    m_myURLGrabber = new URLGrabber(this);
     connect(m_myURLGrabber, &URLGrabber::sigPopup, this, &Klipper::showPopupMenu);
     connect(m_myURLGrabber, &URLGrabber::sigDisablePopup, this, &Klipper::disableURLGrabber);
+    connect(m_historyModel.get(), &HistoryModel::actionInvoked, m_myURLGrabber, &URLGrabber::invokeAction);
 
     /*
      * Load configuration settings
      */
     loadSettings();
 
-    // load previous history if configured
-    if (m_bKeepContents) {
-        loadHistory();
-    }
-
-    m_saveFileTimer = new QTimer(this);
-    m_saveFileTimer->setSingleShot(true);
-    m_saveFileTimer->setInterval(5s);
-    connect(m_saveFileTimer, &QTimer::timeout, this, [this] {
-        const QFuture<bool> future = QtConcurrent::run(&Klipper::saveHistory, this, false);
-        // Destroying the future neither waits nor cancels the asynchronous computation
-    });
-    connect(m_history, &History::changed, this, [this] {
-        if (m_bKeepContents) {
-            m_saveFileTimer->start();
-        }
-    }); // only connect this signal after loading the history, to avoid the action of loading triggering a save
-
     m_clearHistoryAction = m_collection->addAction(QStringLiteral("clear-history"));
     m_clearHistoryAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-clear-history")));
     m_clearHistoryAction->setText(i18nc("@action:inmenu", "C&lear Clipboard History"));
     KGlobalAccel::setGlobalShortcut(m_clearHistoryAction, QKeySequence());
-    connect(m_clearHistoryAction, &QAction::triggered, this, &Klipper::slotAskClearHistory);
+    connect(m_clearHistoryAction, &QAction::triggered, m_historyModel.get(), &HistoryModel::clearHistory);
 
     QString CONFIGURE = QStringLiteral("configure");
     m_configureAction = m_collection->addAction(CONFIGURE);
@@ -149,7 +133,7 @@ Klipper::Klipper(QObject *parent, const KSharedConfigPtr &config)
     m_showBarcodeAction->setIcon(QIcon::fromTheme(QStringLiteral("view-barcode-qr")));
     KGlobalAccel::setGlobalShortcut(m_showBarcodeAction, QKeySequence());
     connect(m_showBarcodeAction, &QAction::triggered, this, [this]() {
-        showBarcode(m_history->first());
+        showBarcode(m_historyModel->first());
     });
 
     // Cycle through history
@@ -171,8 +155,6 @@ Klipper::Klipper(QObject *parent, const KSharedConfigPtr &config)
     KGlobalAccel::setGlobalShortcut(m_showOnMousePos, QKeySequence(Qt::META | Qt::Key_V));
     connect(m_showOnMousePos, &QAction::triggered, this, &Klipper::slotPopupMenu);
 
-    connect(history(), &History::topChanged, this, &Klipper::slotHistoryTopChanged);
-
     connect(this, &Klipper::passivePopup, this, [this](const QString &caption, const QString &text) {
         if (m_notification) {
             m_notification->setTitle(caption);
@@ -190,8 +172,12 @@ Klipper::Klipper(QObject *parent, const KSharedConfigPtr &config)
         connect(registry, &KWayland::Client::Registry::plasmaShellAnnounced, this, [registry, this](quint32 name, quint32 version) {
             if (!m_plasmashell) {
                 m_plasmashell = registry->createPlasmaShell(name, version);
+                m_popup->setPlasmaShell(m_plasmashell);
             }
         });
+        connect(QCoreApplication::instance(), &QCoreApplication::aboutToQuit, registry, [registry] {
+            delete registry; // Avoid freeing resource when gui is deleted
+        });
         registry->create(connection);
         registry->setup();
     }
@@ -210,7 +196,7 @@ QString Klipper::getClipboardContents()
 
 void Klipper::showKlipperPopupMenu()
 {
-    slotPopupMenu();
+    m_popup->show();
 }
 
 void Klipper::showKlipperManuallyInvokeActionMenu()
@@ -225,31 +211,29 @@ void Klipper::setClipboardContents(const QString &s)
         return;
     updateTimestamp();
     HistoryItemPtr item(HistoryItemPtr(new HistoryStringItem(s)));
-    setClipboard(*item, Clipboard | Selection);
-    history()->insert(item);
+    m_clip->setMimeData(item, SystemClipboard::SelectionMode(SystemClipboard::Clipboard | SystemClipboard::Selection));
+    m_historyModel->insert(item);
 }
 
 // DBUS - don't call from Klipper itself
 void Klipper::clearClipboardContents()
 {
     updateTimestamp();
-    slotClearClipboard();
+    m_clip->clear();
 }
 
 // DBUS - don't call from Klipper itself
 void Klipper::clearClipboardHistory()
 {
     updateTimestamp();
-    history()->slotClear();
+    m_historyModel->clear();
     saveSession();
 }
 
 // DBUS - don't call from Klipper itself
 void Klipper::saveClipboardHistory()
 {
-    if (m_bKeepContents) { // save the clipboard eventually
-        saveHistory();
-    }
+    m_historyModel->saveHistory();
 }
 
 void Klipper::slotStartShowTimer()
@@ -278,24 +262,8 @@ void Klipper::loadSettings()
     m_bURLGrabber = KlipperSettings::uRLGrabberEnabled();
     // this will cause it to loadSettings too
     setURLGrabberEnabled(m_bURLGrabber);
-    history()->setMaxSize(KlipperSettings::maxClipItems());
-    history()->model()->setDisplayImages(!m_bIgnoreImages);
 
-    // Convert 4.3 settings
-    if (KlipperSettings::synchronize() != 3) {
-        // 2 was the id of "Ignore selection" radiobutton
-        m_bIgnoreSelection = KlipperSettings::synchronize() == 2;
-        // 0 was the id of "Synchronize contents" radiobutton
-        m_bSynchronize = KlipperSettings::synchronize() == 0;
-        KConfigSkeletonItem *item = KlipperSettings::self()->findItem(QStringLiteral("SyncClipboards"));
-        item->setProperty(m_bSynchronize);
-        item = KlipperSettings::self()->findItem(QStringLiteral("IgnoreSelection"));
-        item->setProperty(m_bIgnoreSelection);
-        item = KlipperSettings::self()->findItem(QStringLiteral("Synchronize")); // Mark property as converted.
-        item->setProperty(3);
-        KlipperSettings::self()->save();
-        KlipperSettings::self()->load();
-    }
+    m_historyModel->loadSettings();
 }
 
 void Klipper::saveSettings() const
@@ -335,119 +303,10 @@ bool Klipper::eventFilter(QObject *filtered, QEvent *event)
     return ret;
 }
 
-bool Klipper::loadHistory()
-{
-    static const char failed_load_warning[] = "Failed to load history resource. Clipboard history cannot be read.";
-    // don't use "appdata", klipper is also a kicker applet
-    QString history_file_path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("klipper/history2.lst"));
-    if (history_file_path.isEmpty()) {
-        qCWarning(KLIPPER_LOG) << failed_load_warning << ": "
-                               << "History file does not exist";
-        return false;
-    }
-    QFile history_file(history_file_path);
-    if (!history_file.open(QIODevice::ReadOnly)) {
-        qCWarning(KLIPPER_LOG) << failed_load_warning << ": " << history_file.errorString();
-        return false;
-    }
-    QDataStream file_stream(&history_file);
-    if (file_stream.atEnd()) {
-        qCWarning(KLIPPER_LOG) << failed_load_warning << ": "
-                               << "Error in reading data";
-        return false;
-    }
-    QByteArray data;
-    quint32 crc;
-    file_stream >> crc >> data;
-    if (crc32(0, reinterpret_cast<unsigned char *>(data.data()), data.size()) != crc) {
-        qCWarning(KLIPPER_LOG) << failed_load_warning << ": "
-                               << "CRC checksum does not match";
-        return false;
-    }
-    QDataStream history_stream(&data, QIODevice::ReadOnly);
-
-    char *version;
-    history_stream >> version;
-    delete[] version;
-
-    QList<HistoryItemPtr> items;
-    for (HistoryItemPtr item = HistoryItem::create(history_stream); item; item = HistoryItem::create(history_stream)) {
-        items.append(item);
-    }
-
-    history()->clearAndBatchInsert(items);
-
-    if (!history()->empty()) {
-        setClipboard(*history()->first(), Clipboard | Selection);
-    }
-
-    return true;
-}
-
-bool Klipper::saveHistory(bool empty)
-{
-    QMutexLocker lock(m_history->model()->mutex());
-    static const char failed_save_warning[] = "Failed to save history. Clipboard history cannot be saved. Reason:";
-    static const QString history_file_path_relative = QStringLiteral("klipper/history2.lst");
-    // don't use "appdata", klipper is also a kicker applet
-    QString history_file_path(QStandardPaths::locate(QStandardPaths::GenericDataLocation, history_file_path_relative));
-    if (history_file_path.isEmpty()) {
-        // try creating the file
-
-        QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
-        if (path.isEmpty()) {
-            qCWarning(KLIPPER_LOG) << failed_save_warning << "cannot locate a standard data location to save the clipboard history.";
-            return false;
-        }
-
-        QDir dir(path);
-        if (!dir.mkpath(QStringLiteral("klipper"))) {
-            qCWarning(KLIPPER_LOG) << failed_save_warning << "Klipper save directory" << path + QStringLiteral("/klipper")
-                                   << "does not exist and cannot be created.";
-            return false;
-        }
-        history_file_path = dir.absoluteFilePath(history_file_path_relative);
-    }
-    if (history_file_path.isEmpty()) {
-        qCWarning(KLIPPER_LOG) << failed_save_warning << "could not construct path to save clipboard history to.";
-        return false;
-    }
-    QSaveFile history_file(history_file_path);
-    if (!history_file.open(QIODevice::WriteOnly)) {
-        qCWarning(KLIPPER_LOG) << failed_save_warning << "unable to open save file" << history_file_path << ":" << history_file.errorString();
-        return false;
-    }
-    QByteArray data;
-    QDataStream history_stream(&data, QIODevice::WriteOnly);
-    history_stream << KLIPPER_VERSION_STRING; // const char*
-
-    if (!empty) {
-        HistoryItemConstPtr item = history()->first();
-        if (item) {
-            do {
-                history_stream << item.get();
-                item = HistoryItemConstPtr(history()->find(item->next_uuid()));
-            } while (item != history()->first());
-        }
-    }
-
-    quint32 crc = crc32(0, reinterpret_cast<unsigned char *>(data.data()), data.size());
-    QDataStream ds(&history_file);
-    ds << crc << data;
-    if (!history_file.commit()) {
-        qCWarning(KLIPPER_LOG) << failed_save_warning << "failed to commit updated save file to disk.";
-        return false;
-    }
-
-    return true;
-}
-
 // save session on shutdown. Don't simply use the c'tor, as that may not be called.
 void Klipper::saveSession()
 {
-    if (m_bKeepContents) { // save the clipboard eventually
-        saveHistory();
-    }
+    m_historyModel->saveHistory();
     saveSettings();
 }
 
@@ -487,42 +346,12 @@ void Klipper::slotConfigure()
         // BUG: 142882
         // Security: If user has save clipboard turned off, old data should be deleted from disk
         if (bKeepContents_old != m_bKeepContents) { // keepContents changed
-            saveHistory(!m_bKeepContents); // save history, empty = !keep
+            m_historyModel->saveHistory(!m_bKeepContents); // save history, empty = !keep
         }
     });
     dlg->show();
 }
 
-void Klipper::slotQuit()
-{
-    // If the menu was just opened, likely the user
-    // selected quit by accident while attempting to
-    // click the Klipper icon.
-    if (m_showTimer.elapsed() < 300) {
-        return;
-    }
-
-    saveSession();
-    int autoStart = KMessageBox::questionTwoActionsCancel(nullptr,
-                                                          i18n("Should Klipper start automatically when you login?"),
-                                                          i18n("Automatically Start Klipper?"),
-                                                          KGuiItem(i18n("Start")),
-                                                          KGuiItem(i18n("Do Not Start")),
-                                                          KStandardGuiItem::cancel(),
-                                                          QStringLiteral("StartAutomatically"));
-
-    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("General"));
-    if (autoStart == KMessageBox::PrimaryAction) {
-        config.writeEntry("AutoStart", true);
-    } else if (autoStart == KMessageBox::SecondaryAction) {
-        config.writeEntry("AutoStart", false);
-    } else // cancel chosen don't quit
-        return;
-    config.sync();
-
-    qApp->quit();
-}
-
 void Klipper::slotIgnored(QClipboard::Mode mode)
 {
     // internal to klipper, ignoring QSpinBox selections
@@ -530,31 +359,31 @@ void Klipper::slotIgnored(QClipboard::Mode mode)
     // This won't quite work, but it's close enough for now.
     // The trouble is that the top selection =! top clipboard
     // but we don't track that yet. We will....
-    if (auto top = history()->first()) {
-        setClipboard(*top, mode == QClipboard::Selection ? Selection : Clipboard);
+    if (auto top = m_historyModel->first()) {
+        m_clip->setMimeData(top, mode == QClipboard::Selection ? SystemClipboard::Selection : SystemClipboard::Clipboard);
     }
 }
 
 void Klipper::slotReceivedEmptyClipboard(QClipboard::Mode mode)
 {
     Q_ASSERT(m_bNoNullClipboard);
-    if (auto top = history()->first()) {
+    if (auto top = m_historyModel->first()) {
         // keep old clipboard after someone set it to null
         qCDebug(KLIPPER_LOG) << "Resetting clipboard (Prevent empty clipboard)";
-        setClipboard(*top, mode == QClipboard::Selection ? Selection : Clipboard, ClipboardUpdateReason::PreventEmptyClipboard);
+        m_clip->setMimeData(top,
+                            mode == QClipboard::Selection ? SystemClipboard::Selection : SystemClipboard::Clipboard,
+                            SystemClipboard::ClipboardUpdateReason::PreventEmptyClipboard);
     }
 }
 
 void Klipper::slotPopupMenu()
 {
-    m_popup->ensureClean();
-    m_popup->slotSetTopActive();
-    showPopupMenu(m_popup);
+    m_popup->show();
 }
 
 void Klipper::slotRepeatAction()
 {
-    auto top = std::static_pointer_cast<const HistoryStringItem>(history()->first());
+    auto top = std::static_pointer_cast<const HistoryStringItem>(m_historyModel->first());
     if (top) {
         m_myURLGrabber->invokeAction(top);
     }
@@ -575,33 +404,22 @@ void Klipper::setURLGrabberEnabled(bool enable)
     m_myURLGrabber->loadSettings();
 }
 
-void Klipper::slotHistoryTopChanged()
+void Klipper::slotHistoryChanged(bool isTop)
 {
-    if (m_clip->isLocked(QClipboard::Selection) || m_clip->isLocked(QClipboard::Clipboard)) {
+    if (!isTop || m_clip->isLocked(QClipboard::Selection) || m_clip->isLocked(QClipboard::Clipboard)) {
         return;
     }
-
-    auto topitem = history()->first();
-    if (topitem) {
-        setClipboard(*topitem, Clipboard | Selection);
-    }
     if (m_bReplayActionInHistory && m_bURLGrabber) {
         slotRepeatAction();
     }
 }
 
-void Klipper::slotClearClipboard()
-{
-    m_clip->clear(QClipboard::Selection);
-    m_clip->clear(QClipboard::Clipboard);
-}
-
 HistoryItemPtr Klipper::applyClipChanges(const QMimeData *clipData)
 {
     Q_ASSERT(m_clip->isLocked(QClipboard::Selection) || m_clip->isLocked(QClipboard::Clipboard));
-    if (!(history()->empty())) {
-        if (m_bIgnoreImages && history()->first()->type() == HistoryItemType::Image) {
-            history()->remove(history()->first());
+    if (m_historyModel->rowCount() > 0) {
+        if (m_bIgnoreImages && m_historyModel->first()->type() == HistoryItemType::Image) {
+            m_historyModel->remove(m_historyModel->first()->uuid());
         }
     }
 
@@ -611,20 +429,13 @@ HistoryItemPtr Klipper::applyClipChanges(const QMimeData *clipData)
     if (clipData->data(QStringLiteral("x-kde-passwordManagerHint")) == QByteArrayLiteral("secret")) {
         saveToHistory = false;
     }
-    if (saveToHistory) {
-        history()->insert(item);
+    if (saveToHistory && item) {
+        m_historyModel->insert(item);
     }
 
     return item;
 }
 
-void Klipper::slotHistoryChanged()
-{
-    if (history()->empty()) {
-        slotClearClipboard();
-    }
-}
-
 void Klipper::checkClipData(QClipboard::Mode mode, const QMimeData *data)
 {
     Q_ASSERT(m_clip->isLocked(QClipboard::Selection) || m_clip->isLocked(QClipboard::Clipboard));
@@ -634,8 +445,15 @@ void Klipper::checkClipData(QClipboard::Mode mode, const QMimeData *data)
     // XXX: I want a better handling of selection/clipboard in general.
     // XXX: Order sensitive code. Must die.
     const bool selectionMode = mode == QClipboard::Selection;
-    if (selectionMode && m_bIgnoreSelection)
+    if (selectionMode && m_bIgnoreSelection) {
+        if (m_bSynchronize) {
+            auto item = HistoryItem::create(data);
+            if (item) [[likely]] { // applyClipChanges can return nullptr
+                m_clip->setMimeData(item, SystemClipboard::Clipboard, SystemClipboard::ClipboardUpdateReason::SyncSelection);
+            }
+        }
         return;
+    }
 
     if (selectionMode && m_bSelectionTextOnly && !data->hasText())
         return;
@@ -648,7 +466,7 @@ void Klipper::checkClipData(QClipboard::Mode mode, const QMimeData *data)
     if (changed) {
         qCDebug(KLIPPER_LOG) << "Synchronize?" << m_bSynchronize;
         if (m_bSynchronize && item) { // applyClipChanges can return nullptr
-            setClipboard(*item, mode == QClipboard::Selection ? Clipboard : Selection);
+            m_clip->setMimeData(item, mode == QClipboard::Selection ? SystemClipboard::Clipboard : SystemClipboard::Selection);
         }
     }
     QString &lastURLGrabberText = selectionMode ? m_lastURLGrabberTextSelection : m_lastURLGrabberTextClipboard;
@@ -667,37 +485,11 @@ void Klipper::checkClipData(QClipboard::Mode mode, const QMimeData *data)
     }
 }
 
-void Klipper::setClipboard(const HistoryItem &item, int mode, ClipboardUpdateReason updateReason)
-{
-    Q_ASSERT((mode & 1) == 0); // Warn if trying to pass a boolean as a mode.
-
-    if (mode & Selection) {
-        qCDebug(KLIPPER_LOG) << "Setting selection to <" << item.text() << ">";
-        QMimeData *mimeData = item.mimeData();
-        if (updateReason == ClipboardUpdateReason::PreventEmptyClipboard) {
-            mimeData->setData(QStringLiteral("application/x-kde-onlyReplaceEmpty"), "1");
-        }
-        m_clip->setMimeData(mimeData, QClipboard::Selection);
-    }
-    if (mode & Clipboard) {
-        qCDebug(KLIPPER_LOG) << "Setting clipboard to <" << item.text() << ">";
-        QMimeData *mimeData = item.mimeData();
-        if (updateReason == ClipboardUpdateReason::PreventEmptyClipboard) {
-            mimeData->setData(QStringLiteral("application/x-kde-onlyReplaceEmpty"), "1");
-        }
-        m_clip->setMimeData(mimeData, QClipboard::Clipboard);
-    }
-}
-
 QStringList Klipper::getClipboardHistoryMenu()
 {
     QStringList menu;
-    auto item = history()->first();
-    if (item) {
-        do {
-            menu << item->text();
-            item = history()->find(item->next_uuid());
-        } while (item != history()->first());
+    for (int i = 0, count = m_historyModel->rowCount(); i < count; ++i) {
+        menu.emplace_back(m_historyModel->index(i).data(Qt::DisplayRole).toString());
     }
 
     return menu;
@@ -705,16 +497,7 @@ QStringList Klipper::getClipboardHistoryMenu()
 
 QString Klipper::getClipboardHistoryItem(int i)
 {
-    auto item = history()->first();
-    if (item) {
-        do {
-            if (i-- == 0) {
-                return item->text();
-            }
-            item = history()->find(item->next_uuid());
-        } while (item != history()->first());
-    }
-    return QString();
+    return m_historyModel->index(i).data(Qt::DisplayRole).toString();
 }
 
 //
@@ -807,26 +590,11 @@ void Klipper::showBarcode(std::shared_ptr<const HistoryItem> item)
     dlg->open();
 }
 
-void Klipper::slotAskClearHistory()
-{
-    int clearHist = KMessageBox::warningContinueCancel(nullptr,
-                                                       i18n("Do you really want to clear and delete the entire clipboard history?"),
-                                                       i18n("Clear Clipboard History"),
-                                                       KStandardGuiItem::del(),
-                                                       KStandardGuiItem::cancel(),
-                                                       QStringLiteral("klipperClearHistoryAskAgain"),
-                                                       KMessageBox::Dangerous);
-    if (clearHist == KMessageBox::Continue) {
-        history()->slotClear();
-        saveHistory();
-    }
-}
-
 void Klipper::slotCycleNext()
 {
     // do cycle and show popup only if we have something in clipboard
-    if (m_history->first()) {
-        m_history->cycleNext();
+    if (m_historyModel->first()) {
+        m_historyCycler->cycleNext();
         Q_EMIT passivePopup(i18n("Clipboard history"), cycleText());
     }
 }
@@ -834,8 +602,8 @@ void Klipper::slotCycleNext()
 void Klipper::slotCyclePrev()
 {
     // do cycle and show popup only if we have something in clipboard
-    if (m_history->first()) {
-        m_history->cyclePrev();
+    if (m_historyModel->first()) {
+        m_historyCycler->cyclePrev();
         Q_EMIT passivePopup(i18n("Clipboard history"), cycleText());
     }
 }
@@ -844,18 +612,18 @@ QString Klipper::cycleText() const
 {
     const int WIDTH_IN_PIXEL = 400;
 
-    auto itemprev = m_history->prevInCycle();
-    auto item = m_history->first();
-    auto itemnext = m_history->nextInCycle();
+    auto itemPrev = m_historyCycler->prevInCycle();
+    auto item = m_historyModel->first();
+    auto itemNext = m_historyCycler->nextInCycle();
 
-    QFontMetrics font_metrics(m_popup->fontMetrics());
+    QFontMetrics font_metrics(QWidget().fontMetrics());
     QString result(QStringLiteral("<table>"));
 
-    if (itemprev) {
+    if (itemPrev) {
         result += QLatin1String("<tr><td>");
         result += i18n("up");
         result += QLatin1String("</td><td>");
-        result += font_metrics.elidedText(itemprev->text().simplified().toHtmlEscaped(), Qt::ElideMiddle, WIDTH_IN_PIXEL);
+        result += font_metrics.elidedText(itemPrev->text().simplified().toHtmlEscaped(), Qt::ElideMiddle, WIDTH_IN_PIXEL);
         result += QLatin1String("</td></tr>");
     }
 
@@ -865,11 +633,11 @@ QString Klipper::cycleText() const
     result += font_metrics.elidedText(item->text().simplified().toHtmlEscaped(), Qt::ElideMiddle, WIDTH_IN_PIXEL);
     result += QLatin1String("</b></td></tr>");
 
-    if (itemnext) {
+    if (itemNext) {
         result += QLatin1String("<tr><td>");
         result += i18n("down");
         result += QLatin1String("</td><td>");
-        result += font_metrics.elidedText(itemnext->text().simplified().toHtmlEscaped(), Qt::ElideMiddle, WIDTH_IN_PIXEL);
+        result += font_metrics.elidedText(itemNext->text().simplified().toHtmlEscaped(), Qt::ElideMiddle, WIDTH_IN_PIXEL);
         result += QLatin1String("</td></tr>");
     }
 
