@@ -19,7 +19,9 @@
 
 #include "../c_ptr.h"
 #include "config-X11.h"
+#include "historyitem.h"
 #include "klipper_debug.h"
+#include <wayland-client-core.h>
 
 #if HAVE_X11
 #include <X11/Xlib.h>
@@ -100,16 +102,50 @@ SystemClipboard::~SystemClipboard()
 {
 }
 
-void SystemClipboard::clear(QClipboard::Mode mode)
+void SystemClipboard::clear(SelectionMode mode)
 {
-    Ignore lock(mode == QClipboard::Selection ? m_selectionLocklevel : m_clipboardLocklevel);
-    m_clip->clear(mode);
+    Q_ASSERT((mode & 1) == 0); // Warn if trying to pass a boolean as a mode.
+
+    if (mode & Selection) {
+        Ignore lock(m_selectionLocklevel);
+        m_clip->clear(QClipboard::Selection);
+    }
+    if (mode & Clipboard) {
+        Ignore lock(m_clipboardLocklevel);
+        m_clip->clear(QClipboard::Clipboard);
+    }
 }
 
-void SystemClipboard::setMimeData(QMimeData *data, QClipboard::Mode mode)
+void SystemClipboard::setMimeData(const HistoryItemConstPtr &data, SelectionMode mode, ClipboardUpdateReason updateReason)
 {
-    Ignore lock(mode == QClipboard::Selection ? m_selectionLocklevel : m_clipboardLocklevel);
-    m_clip->setMimeData(data, mode);
+    Q_ASSERT((mode & 1) == 0); // Warn if trying to pass a boolean as a mode.
+
+    if (mode & Selection) {
+        Ignore lock(m_selectionLocklevel);
+        QMimeData *mimeData = data->mimeData();
+        if (updateReason == ClipboardUpdateReason::PreventEmptyClipboard) {
+            mimeData->setData(QStringLiteral("application/x-kde-onlyReplaceEmpty"), "1");
+        }
+        qCDebug(KLIPPER_LOG) << "Setting selection to <" << mimeData->text() << ">";
+        m_clip->setMimeData(mimeData, QClipboard::Selection);
+    }
+    if (mode & Clipboard) {
+        QMimeData *mimeData = data->mimeData(); // NOTE: this has to be a new mimeData because setMimeData will take ownership
+        if (updateReason == ClipboardUpdateReason::PreventEmptyClipboard) {
+            mimeData->setData(QStringLiteral("application/x-kde-onlyReplaceEmpty"), "1");
+        } else if (updateReason == ClipboardUpdateReason::SyncSelection) {
+            // When plasmashell is not focused, klipper will not receive new clip data immediately. This type is used to filter out selections.
+            mimeData->setData(QStringLiteral("application/x-kde-syncselection"), "1");
+        }
+        qCDebug(KLIPPER_LOG) << "Setting clipboard to <" << mimeData->text() << ">";
+        QMetaObject::invokeMethod(
+            this,
+            [this, mimeData]() {
+                Ignore lock(m_clipboardLocklevel);
+                m_clip->setMimeData(mimeData, QClipboard::Clipboard);
+            },
+            updateReason == ClipboardUpdateReason::SyncSelection ? Qt::QueuedConnection : Qt::DirectConnection);
+    }
 }
 
 bool SystemClipboard::isLocked(QClipboard::Mode mode)
@@ -161,6 +197,10 @@ void SystemClipboard::checkClipData(QClipboard::Mode mode)
         return; // unknown, ignore
     }
 
+    if (data->hasFormat(QStringLiteral("application/x-kde-syncselection"))) {
+        return;
+    }
+
     Q_ASSERT_X((mode == QClipboard::Clipboard && m_clipboardLocklevel == 1) || (mode == QClipboard::Selection && m_selectionLocklevel == 1),
                Q_FUNC_INFO,
                qPrintable(QStringLiteral("%1 %2").arg(QString::number(m_clipboardLocklevel), QString::number(m_selectionLocklevel))));
