@@ -14,10 +14,6 @@
 #include <KJob>
 #include <KLocalizedString>
 
-#include <Plasma/DataEngine>
-#include <Plasma/DataEngineConsumer>
-#include <Plasma/ServiceJob>
-
 #include "job.h"
 #include "job_p.h"
 
@@ -44,7 +40,7 @@ JobsModel::JobsModel()
         endRemoveRows();
     });
 
-    connect(d, &JobsModelPrivate::jobViewChanged, this, [this](int row, Job *job, const QVector<int> &roles) {
+    connect(d, &JobsModelPrivate::jobViewChanged, this, [this](int row, Job *job, const QList<int> &roles) {
         Q_UNUSED(job);
         const QModelIndex idx = index(row, 0);
         Q_EMIT dataChanged(idx, idx, roles);
@@ -57,13 +53,13 @@ JobsModel::~JobsModel() = default;
 
 JobsModel::Ptr JobsModel::createJobsModel()
 {
-    static QWeakPointer<JobsModel> s_instance;
-    if (!s_instance) {
-        QSharedPointer<JobsModel> ptr(new JobsModel());
-        s_instance = ptr.toWeakRef();
+    static std::weak_ptr<JobsModel> s_instance;
+    if (s_instance.expired()) {
+        std::shared_ptr<JobsModel> ptr(new JobsModel());
+        s_instance = ptr;
         return ptr;
     }
-    return s_instance.toStrongRef();
+    return s_instance.lock();
 }
 
 bool JobsModel::init()
