@@ -9,6 +9,8 @@
 #include "notification.h"
 #include "notification_p.h"
 
+#include <algorithm>
+
 #include <QDBusArgument>
 #include <QDebug>
 #include <QImageReader>
@@ -25,11 +27,16 @@
 using namespace NotificationManager;
 using namespace Qt::StringLiterals;
 
+QCache<uint, QImage> Notification::Private::s_imageCache = QCache<uint, QImage>{};
+
 Notification::Private::Private()
 {
 }
 
-Notification::Private::~Private() = default;
+Notification::Private::~Private()
+{
+    // The image cache is cleared by AbstractNotificationsModel::pendingRemovalTimer
+}
 
 QString Notification::Private::sanitize(const QString &text)
 {
@@ -55,25 +62,26 @@ QString Notification::Private::sanitize(const QString &text)
         return t;
     }
 
-    QXmlStreamReader r(QStringLiteral("<html>") + t + QStringLiteral("</html>"));
+    t = u"<html>" + std::move(t) + u"</html>";
+    QXmlStreamReader r(t);
     QString result;
     QXmlStreamWriter out(&result);
 
-    const QList<QString> allowedTags = {"b", "i", "u", "img", "a", "html", "br", "table", "tr", "td"};
+    static constexpr std::array<QStringView, 10> allowedTags{u"b", u"i", u"u", u"img", u"a", u"html", u"br", u"table", u"tr", u"td"};
 
     out.writeStartDocument();
     while (!r.atEnd()) {
         r.readNext();
 
         if (r.tokenType() == QXmlStreamReader::StartElement) {
-            const QString name = r.name().toString();
-            if (!allowedTags.contains(name)) {
+            const QStringView name = r.name();
+            if (std::ranges::find(allowedTags, name) == allowedTags.end()) {
                 continue;
             }
             out.writeStartElement(name);
             if (name == QLatin1String("img")) {
-                auto src = r.attributes().value("src").toString();
-                auto alt = r.attributes().value("alt").toString();
+                const QString src = r.attributes().value("src").toString();
+                const QStringView alt = r.attributes().value("alt");
 
                 const QUrl url(src);
                 if (url.isLocalFile()) {
@@ -82,24 +90,23 @@ QString Notification::Private::sanitize(const QString &text)
                     // image denied for security reasons! Do not copy the image src here!
                 }
 
-                out.writeAttribute(QStringLiteral("alt"), alt);
+                out.writeAttribute(u"alt", alt);
             }
             if (name == QLatin1Char('a')) {
-                out.writeAttribute(QStringLiteral("href"), r.attributes().value("href").toString());
+                out.writeAttribute(u"href", r.attributes().value("href"));
             }
         }
 
         if (r.tokenType() == QXmlStreamReader::EndElement) {
-            const QString name = r.name().toString();
-            if (!allowedTags.contains(name)) {
+            const QStringView name = r.name();
+            if (std::ranges::find(allowedTags, name) == allowedTags.end()) {
                 continue;
             }
             out.writeEndElement();
         }
 
         if (r.tokenType() == QXmlStreamReader::Characters) {
-            const auto text = r.text().toString();
-            out.writeCharacters(text); // this auto escapes chars -> HTML entities
+            out.writeCharacters(r.text()); // this auto escapes chars -> HTML entities
         }
     }
     out.writeEndDocument();
@@ -111,7 +118,7 @@ QString Notification::Private::sanitize(const QString &text)
 
     // The Text.StyledText format handles only html3.2 stuff and &apos; is html4 stuff
     // so we need to replace it here otherwise it will not render at all.
-    result.replace(QLatin1String("&apos;"), QChar('\''));
+    result.replace(QLatin1String("&apos;"), QChar(u'\''));
 
     return result;
 }
@@ -206,7 +213,7 @@ void Notification::Private::loadImagePath(const QString &path)
     // image_path and appIcon should either be a URL with file scheme or the name of a themed icon.
     // We're lenient and also allow local paths.
 
-    image = QImage(); // clear
+    s_imageCache.remove(id); // clear
     icon.clear();
 
     QUrl imageUrl;
@@ -230,13 +237,13 @@ void Notification::Private::loadImagePath(const QString &path)
     QImageReader reader(imageUrl.toLocalFile());
     reader.setAutoTransform(true);
 
-    const QSize imageSize = reader.size();
-    if (imageSize.isValid() && (imageSize.width() > maximumImageSize().width() || imageSize.height() > maximumImageSize().height())) {
-        const QSize thumbnailSize = imageSize.scaled(maximumImageSize(), Qt::KeepAspectRatio);
-        reader.setScaledSize(thumbnailSize);
+    if (QSize imageSize = reader.size(); imageSize.isValid()) {
+        if (imageSize.width() > maximumImageSize().width() || imageSize.height() > maximumImageSize().height()) {
+            imageSize = imageSize.scaled(maximumImageSize(), Qt::KeepAspectRatio);
+            reader.setScaledSize(imageSize);
+        }
+        s_imageCache.insert(id, new QImage(reader.read()), imageSize.width() * imageSize.height());
     }
-
-    image = reader.read();
 }
 
 QString Notification::Private::defaultComponentName()
@@ -245,7 +252,7 @@ QString Notification::Private::defaultComponentName()
     return QStringLiteral("plasma_workspace");
 }
 
-QSize Notification::Private::maximumImageSize()
+constexpr QSize Notification::Private::maximumImageSize()
 {
     return QSize(256, 256);
 }
@@ -324,6 +331,9 @@ void Notification::Private::setDesktopEntry(const QString &desktopEntry)
         if (configSources.isEmpty()) {
             configSources = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("knotifications5/%1.notifyrc").arg(notifyRcName));
         }
+        // `QStandardPaths` follows the order of precedence given by `$XDG_DATA_DIRS
+        // (more priority goest first), but for `addConfigSources() it is the opposite
+        std::reverse(configSources.begin(), configSources.end());
         config.addConfigSources(configSources);
 
         KConfigGroup globalGroup(&config, u"Global"_s);
@@ -415,11 +425,20 @@ void Notification::Private::processHints(const QVariantMap &hints)
         it = hints.find(QStringLiteral("icon_data"));
     }
 
+    QImage *image = nullptr;
     if (it != end) {
-        image = decodeNotificationSpecImageHint(it->value<QDBusArgument>());
+        QImage imageFromHint(decodeNotificationSpecImageHint(it->value<QDBusArgument>()));
+        if (!imageFromHint.isNull()) {
+            Q_ASSERT_X(imageFromHint.width() > 0 && imageFromHint.height() > 0,
+                       Q_FUNC_INFO,
+                       qPrintable(QStringLiteral("%1 %2").arg(QString::number(imageFromHint.width()), QString::number(imageFromHint.height()))));
+            sanitizeImage(imageFromHint);
+            image = new QImage(imageFromHint);
+            s_imageCache.insert(id, image, imageFromHint.width() * imageFromHint.height());
+        }
     }
 
-    if (image.isNull()) {
+    if (!image) {
         it = hints.find(QStringLiteral("image-path"));
         if (it == end) {
             it = hints.find(QStringLiteral("image_path"));
@@ -429,8 +448,6 @@ void Notification::Private::processHints(const QVariantMap &hints)
             loadImagePath(it->toString());
         }
     }
-
-    sanitizeImage(image);
 }
 
 void Notification::Private::setUrgency(Notifications::Urgency urgency)
@@ -561,17 +578,19 @@ QString Notification::icon() const
 void Notification::setIcon(const QString &icon)
 {
     d->loadImagePath(icon);
-    Private::sanitizeImage(d->image);
 }
 
 QImage Notification::image() const
 {
-    return d->image;
+    if (d->s_imageCache.contains(d->id)) {
+        return *d->s_imageCache.object(d->id);
+    }
+    return QImage();
 }
 
 void Notification::setImage(const QImage &image)
 {
-    d->image = image;
+    d->s_imageCache.insert(d->id, new QImage(image));
 }
 
 QString Notification::desktopEntry() const
