@@ -158,12 +158,12 @@ protected:
         };
         QFuture<QIcon> future = QtConcurrent::run(readIcon, pipeFds[0]);
         auto watcher = new QFutureWatcher<QIcon>();
-        watcher->setFuture(future);
         connect(watcher, &QFutureWatcher<QIcon>::finished, this, [this, watcher] {
             icon = watcher->future().result();
             Q_EMIT iconChanged();
         });
         connect(watcher, &QFutureWatcher<QIcon>::finished, watcher, &QObject::deleteLater);
+        watcher->setFuture(future);
     }
     void org_kde_plasma_window_themed_icon_name_changed(const QString &name) override
     {
@@ -532,7 +532,7 @@ auto WaylandTasksModel::Private::findWindow(PlasmaWindow *window) const
 
 void WaylandTasksModel::Private::addWindow(PlasmaWindow *window)
 {
-    if (findWindow(window) != windows.end() || transients.contains(window)) {
+    if (findWindow(window) != windows.end()) {
         return;
     }
 
@@ -556,7 +556,6 @@ void WaylandTasksModel::Private::addWindow(PlasmaWindow *window)
             appDataCache.remove(window);
             lastActivated.remove(window);
             q->endRemoveRows();
-        } else { // Could be a transient.
             // Removing a transient might change the demands attention state of the leader.
             if (transients.remove(window)) {
                 if (PlasmaWindow *leader = transientsDemandingAttention.key(window)) {
@@ -651,23 +650,11 @@ void WaylandTasksModel::Private::addWindow(PlasmaWindow *window)
             if (leader) { // leader change.
                 transients.insert(window, leader);
             } else { // lost a leader, add to regular windows list.
-                Q_ASSERT(findWindow(window) == windows.end());
-
-                const int count = windows.size();
-                q->beginInsertRows(QModelIndex(), count, count);
-                windows.emplace_back(window);
-                q->endInsertRows();
+                dataChanged(window, SkipTaskbar);
             }
         } else if (leader) { // gained a leader, remove from regular windows list.
-            auto it = findWindow(window);
-            Q_ASSERT(it != windows.end());
-
-            const int row = it - windows.begin();
-            q->beginRemoveRows(QModelIndex(), row, row);
-            windows.erase(it);
-            appDataCache.remove(window);
-            lastActivated.remove(window);
-            q->endRemoveRows();
+            transients.insert(window, leader);
+            dataChanged(window, SkipTaskbar);
         }
     });
 
@@ -783,15 +770,15 @@ void WaylandTasksModel::Private::addWindow(PlasmaWindow *window)
             transientsDemandingAttention.insert(leader, window);
             dataChanged(leader, QVector<int>{IsDemandingAttention});
         }
-    } else {
-        const int count = windows.size();
-
-        q->beginInsertRows(QModelIndex(), count, count);
-
-        windows.emplace_back(window);
-
-        q->endInsertRows();
     }
+
+    const int count = windows.size();
+
+    q->beginInsertRows(QModelIndex(), count, count);
+
+    windows.emplace_back(window);
+
+    q->endInsertRows();
 }
 
 const AppData &WaylandTasksModel::Private::appData(PlasmaWindow *window)
@@ -821,14 +808,14 @@ QString WaylandTasksModel::Private::mimeType()
 {
     // Use a unique format id to make this intentionally useless for
     // cross-process DND.
-    return QStringLiteral("windowsystem/winid+") + uuid.toString();
+    return u"windowsystem/winid+" + uuid.toString();
 }
 
 QString WaylandTasksModel::Private::groupMimeType()
 {
     // Use a unique format id to make this intentionally useless for
     // cross-process DND.
-    return QStringLiteral("windowsystem/multiple-winids+") + uuid.toString();
+    return u"windowsystem/multiple-winids+" + uuid.toString();
 }
 
 void WaylandTasksModel::Private::dataChanged(PlasmaWindow *window, int role)
@@ -938,7 +925,7 @@ QVariant WaylandTasksModel::data(const QModelIndex &index, int role) const
     } else if (role == IsDemandingAttention) {
         return window->windowState.testFlag(PlasmaWindow::state::state_demands_attention) || d->transientsDemandingAttention.contains(window);
     } else if (role == SkipTaskbar) {
-        return window->windowState.testFlag(PlasmaWindow::state::state_skiptaskbar) || d->appData(window).skipTaskbar;
+        return window->windowState.testFlag(PlasmaWindow::state::state_skiptaskbar) || d->appData(window).skipTaskbar || d->transients.contains(window);
     } else if (role == SkipPager) {
         // FIXME Implement.
     } else if (role == AppPid) {
