@@ -465,7 +465,7 @@ const AppData &XWindowTasksModel::Private::appData(WId window)
     // can't map to an URL due to existing outside the regular system
     // environment, e.g. wine clients.
     if (data.id.isEmpty() && data.url.isEmpty()) {
-        data.id = windowInfo(window)->windowClassClass();
+        data.id = QString::fromLocal8Bit(windowInfo(window)->windowClassClass());
         return *appDataCache.emplace(window, std::move(data));
     }
 
@@ -534,7 +534,7 @@ QUrl XWindowTasksModel::Private::windowUrl(WId window)
             // applications: URLs are used to refer to applications by their KService::menuId
             // (i.e. .desktop file name) rather than the absolute path to a .desktop file.
             if (!menuId.isEmpty()) {
-                return QUrl(QStringLiteral("applications:") + menuId);
+                return QUrl(QString(u"applications:" + menuId));
             }
 
             return QUrl::fromLocalFile(service->entryPath());
@@ -549,7 +549,7 @@ QUrl XWindowTasksModel::Private::windowUrl(WId window)
         }
     }
 
-    return windowUrlFromMetadata(info->windowClassClass(), info->pid(), rulesConfig, info->windowClassName());
+    return windowUrlFromMetadata(QString::fromLocal8Bit(info->windowClassClass()), info->pid(), rulesConfig, QString::fromLocal8Bit(info->windowClassName()));
 }
 
 QUrl XWindowTasksModel::Private::launcherUrl(WId window, bool encodeFallbackIcon)
@@ -592,7 +592,7 @@ QUrl XWindowTasksModel::Private::launcherUrl(WId window, bool encodeFallbackIcon
     QBuffer buffer(&bytes);
     buffer.open(QIODevice::WriteOnly);
     pixmap.save(&buffer, "PNG");
-    uQuery.addQueryItem(QStringLiteral("iconData"), bytes.toBase64(QByteArray::Base64UrlEncoding));
+    uQuery.addQueryItem(QStringLiteral("iconData"), QString::fromLatin1(bytes.toBase64(QByteArray::Base64UrlEncoding)));
 
     url.setQuery(uQuery);
 
