@@ -91,7 +91,11 @@ DesktopView::DesktopView(Plasma::Corona *corona, QScreen *targetScreen)
             resetAccentColor();
         }
     });
-    connect(this, &ContainmentView::containmentChanged, this, &DesktopView::slotContainmentChanged);
+
+#if PROJECT_VERSION_PATCH >= 80 || PROJECT_VERSION_MINOR >= 80
+    m_showPreviewBanner = KConfigGroup(KSharedConfig::openConfig(u"kdeglobals"_s), u"General"_s).readEntry("ShowDesktopPreviewBanner", true);
+    Q_EMIT showPreviewBannerChanged();
+#endif
 }
 
 DesktopView::~DesktopView()
@@ -195,11 +199,16 @@ void DesktopView::resetAccentColor()
 }
 
 #if PROJECT_VERSION_PATCH >= 80 || PROJECT_VERSION_MINOR >= 80
+#include <KIO/JobUiDelegateFactory>
+#include <KIO/OpenUrlJob>
+#include <KMessageBox>
+#include <QClipboard>
+#include <QGuiApplication>
+#include <QMenu>
+
 bool DesktopView::showPreviewBanner() const
 {
-    static const bool shouldShowPreviewBanner =
-        !KConfigGroup(KSharedConfig::openConfig("kdeglobals"), u"General"_s).readEntry("HideDesktopPreviewBanner", false);
-    return shouldShowPreviewBanner;
+    return m_showPreviewBanner;
 }
 
 QString DesktopView::previewBannerTitle() const
@@ -268,6 +277,60 @@ QString DesktopView::previewBannerText() const
 {
     return i18nc("@info:usagetip", "Visit bugs.kde.org to report issues");
 }
+
+void DesktopView::showPreviewBannerMenu(const QPoint &pos)
+{
+    auto menu = new QMenu();
+    menu->setAttribute(Qt::WA_DeleteOnClose);
+
+    QAction *copyVersionAction = new QAction(QIcon::fromTheme(u"edit-copy-symbolic"_s), i18nc("@action:button", "Copy Plasma Version"));
+    connect(copyVersionAction, &QAction::triggered, [] {
+        QGuiApplication::clipboard()->setText(QStringLiteral(WORKSPACE_VERSION_STRING));
+    });
+    menu->addAction(copyVersionAction);
+
+    QAction *reportBugAction = new QAction(QIcon::fromTheme(u"tools-report-bug-symbolic"_s), i18nc("@action:button", "Report a Bug…"));
+    connect(reportBugAction, &QAction::triggered, [] {
+        auto job = new KIO::OpenUrlJob(QUrl(u"https://bugs.kde.org/"_s));
+        job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, nullptr));
+        job->start();
+    });
+    menu->addAction(reportBugAction);
+
+    menu->addSeparator();
+
+    auto hideMenu = menu->addMenu(QIcon::fromTheme(u"view-hidden-symbolic"_s), i18nc("@title:menu", "Hide Preview Banner"));
+
+    QAction *hidePreviewBannerTemporarilyAction =
+        new QAction(i18nc("@action:button Hide the preview banner until the system is restarted", "Hide Until Restart"));
+    connect(hidePreviewBannerTemporarilyAction, &QAction::triggered, [&]() {
+        m_showPreviewBanner = false;
+        Q_EMIT showPreviewBannerChanged();
+    });
+    hideMenu->addAction(hidePreviewBannerTemporarilyAction);
+
+    QAction *hidePreviewBannerPermenanentlyAction = new QAction(i18nc("@action:button Hide the preview banner permanently", "Hide Permanently…"));
+    connect(hidePreviewBannerPermenanentlyAction, &QAction::triggered, [&]() {
+        if (KMessageBox::warningContinueCancel(
+                nullptr,
+                xi18nc(
+                    "@info",
+                    "Are you sure you want to permanently hide the preview banner?<nl/><nl/>This action can only be undone by removing the line beginning with "
+                    "<icode>ShowDesktopPreviewBanner</icode> in the <filename>kdeglobals</filename> config file."),
+                i18nc("@title:window", "Hide Preview Banner?"))
+            == KMessageBox::Continue) {
+            KConfigGroup config(KSharedConfig::openConfig(u"kdeglobals"_s), u"General"_s);
+            config.writeEntry("ShowDesktopPreviewBanner", false);
+            config.sync();
+
+            m_showPreviewBanner = false;
+            Q_EMIT showPreviewBannerChanged();
+        }
+    });
+    hideMenu->addAction(hidePreviewBannerPermenanentlyAction);
+
+    menu->popup(pos);
+}
 #endif
 
 QVariantMap DesktopView::candidateContainmentsGraphicItems() const
@@ -373,6 +436,8 @@ void DesktopView::showConfigurationInterface(Plasma::Applet *applet)
         return;
     }
 
+    applet->containment()->corona()->setEditMode(false);
+
     Plasma::Containment *cont = qobject_cast<Plasma::Containment *>(applet);
 
     if (cont && cont->isContainment() && cont->containmentType() == Plasma::Containment::Desktop) {
@@ -419,9 +484,27 @@ void DesktopView::slotContainmentChanged()
     if (m_containment) {
         connect(m_containment, &Plasma::Containment::screenChanged, this, &DesktopView::slotScreenChanged);
         slotScreenChanged(m_containment->screen());
+
+        QAction *desktopEditMode = new QAction(QIcon::fromTheme(QStringLiteral("document-edit")), i18n("Enter Edit Mode"), m_containment);
+        QAction *editMode = m_containment->corona()->action(QStringLiteral("edit mode"));
+        m_containment->setInternalAction(QStringLiteral("desktop edit mode"), desktopEditMode);
+        connect(desktopEditMode, &QAction::triggered, editMode, &QAction::triggered);
+        connect(desktopEditMode, &QAction::triggered, [&]() {
+            m_enteredEditMode = true;
+        });
+        connect(m_containment->corona(), &Plasma::Corona::editModeChanged, this, [&](bool editMode) {
+            if (!editMode) {
+                m_enteredEditMode = false;
+            }
+        });
     }
 }
 
+bool DesktopView::enteredEditMode() const
+{
+    return m_enteredEditMode;
+}
+
 void DesktopView::slotScreenChanged(int newId)
 {
     if (m_containmentScreenId == newId) {
@@ -449,7 +532,7 @@ void DesktopView::setAccentColorFromWallpaper(const QColor &accentColor)
     if (!usedInAccentColor()) {
         return;
     }
-    QDBusMessage applyAccentColor = QDBusMessage::createMethodCall("org.kde.plasmashell.accentColor", "/AccentColor", "", "setAccentColor");
+    QDBusMessage applyAccentColor = QDBusMessage::createMethodCall(u"org.kde.plasmashell.accentColor"_s, u"/AccentColor"_s, QString(), u"setAccentColor"_s);
     applyAccentColor << accentColor.rgba();
     QDBusConnection::sessionBus().send(applyAccentColor);
 }
