@@ -6,6 +6,7 @@
 
 #include "panelconfigview.h"
 #include "config-X11.h"
+#include "desktopview.h"
 #include "panelshadows_p.h"
 #include "panelview.h"
 #include "shellcorona.h"
@@ -32,7 +33,6 @@
 #include <Plasma/Containment>
 #include <Plasma/PluginLoader>
 #include <PlasmaQuick/Dialog>
-#include <PlasmaQuick/PlasmaShellWaylandIntegration>
 
 #include <KWayland/Client/plasmashell.h>
 #include <KWayland/Client/surface.h>
@@ -178,7 +178,7 @@ void PanelRulerView::showEvent(QShowEvent *ev)
     PlasmaWindow::showEvent(ev);
 }
 
-void PanelRulerView::focusOutEvent(QFocusEvent *ev)
+void PanelRulerView::focusOutEvent(QFocusEvent *)
 {
     QWindow *focusWindow = QGuiApplication::focusWindow();
 
@@ -197,11 +197,6 @@ PanelConfigView::PanelConfigView(Plasma::Containment *containment, PanelView *pa
     , m_panelView(panelView)
     , m_sharedQmlEngine(std::make_unique<PlasmaQuick::SharedQmlEngine>(this))
 {
-    if (KWindowSystem::isPlatformX11()) {
-        KX11Extras::setType(winId(), NET::AppletPopup);
-    } else {
-        PlasmaShellWaylandIntegration::get(this)->setRole(QtWayland::org_kde_plasma_surface::role::role_appletpopup);
-    }
     setProperty("restrictedPopupGeometry", QVariant(containment->corona()->availableScreenRect(m_containment->screen())));
     connect(m_containment, &Plasma::Containment::screenChanged, this, [this](int screen) {
         setProperty("restrictedPopupGeometry", QVariant(m_containment->corona()->availableScreenRect(screen)));
@@ -284,7 +279,7 @@ void PanelConfigView::addPanelSpacer()
     }
     // Add a spacer at the end *except* if there is exactly one spacer already
     // this to trigger the panel centering mode of the spacer in a slightly more discoverable way
-    c->evaluateScript(QStringLiteral("panel = panelById(") + QString::number(m_containment->id())
+    c->evaluateScript(u"panel = panelById(" + QString::number(m_containment->id())
                       + QStringLiteral(");"
                                        "var spacers = panel.widgets(\"org.kde.plasma.panelspacer\");"
                                        "if (spacers.length === 1) {"
@@ -392,10 +387,22 @@ void PanelConfigView::focusVisibilityCheck(QWindow *focusWindow)
             return;
         }
     }
-    if (auto popup = qobject_cast<const PopupPlasmaWindow *>(oldFocusWindow); popup && oldFocusWindow != this) {
+    // When the dialogs that appear when hovering applets in the panel close,
+    // the focus will switch back to the desktop. If that happens, we
+    // instead want to requestActivate to preserve it.
+    auto popup = qobject_cast<const PopupPlasmaWindow *>(oldFocusWindow);
+    auto desktop = qobject_cast<const DesktopView *>(focusWindow);
+    if (desktop && popup && oldFocusWindow != this) {
         requestActivate();
         return;
     }
+
+    // Never hide when the user is handling desktop widgets, e.g. drag
+    // and dropping them around.
+    if (auto desktop = qobject_cast<const DesktopView *>(focusWindow)) {
+        return;
+    }
+
     // Don't close if the user is directly manipulating the panel
     if (m_panelView->mouseGrabberItem()) {
         return;
