@@ -6,8 +6,11 @@
 
 #include <config-plasma.h>
 
+#include <chrono>
+
 #include "autohidescreenedge.h"
 #include "debug.h"
+#include "desktopview.h"
 #include "panelconfigview.h"
 #include "panelshadows_p.h"
 #include "panelview.h"
@@ -17,6 +20,9 @@
 #include <QApplication>
 #include <QDebug>
 #include <QGuiApplication>
+#include <QOffscreenSurface>
+#include <QOpenGLContext>
+#include <QOpenGLFunctions>
 #include <QQmlContext>
 #include <QQmlEngine>
 #include <QRegularExpression>
@@ -35,7 +41,6 @@
 #include <NETWM>
 #include <qpa/qplatformwindow_p.h>
 #endif
-#include <chrono>
 
 using namespace std::chrono_literals;
 using namespace Qt::StringLiterals;
@@ -133,6 +138,47 @@ PanelView::~PanelView()
     }
 }
 
+static bool vendorIsNVidia()
+{
+    QOffscreenSurface surface;
+    surface.create();
+    QOpenGLContext context;
+    context.create();
+    if (context.makeCurrent(&surface)) {
+        QOpenGLFunctions funcs(&context);
+        const QString vendor = QString::fromLocal8Bit(reinterpret_cast<const char *>(funcs.glGetString(GL_VENDOR)));
+        return vendor.contains(u"NVIDIA", Qt::CaseInsensitive);
+    }
+    return false;
+}
+
+bool PanelView::isUnsupportedEnvironment() const
+{
+    // See BUG 475468 on why is this needed.
+
+    // It is a static variable: compute it once and cache the results because
+    // we don't expect such configuration to change at runtime.
+    static const bool unsupported = []() {
+#if HAVE_X11
+        const auto isX11 = KWindowSystem::isPlatformX11();
+#else
+        const auto isX11 = false;
+#endif
+        return isX11 && vendorIsNVidia();
+    }();
+    return unsupported;
+}
+
+bool PanelView::defaultFloating() const
+{
+    return isUnsupportedEnvironment() ? false : true;
+}
+
+PanelView::OpacityMode PanelView::defaultOpacityMode() const
+{
+    return isUnsupportedEnvironment() ? PanelView::OpacityMode::Translucent : PanelView::OpacityMode::Adaptive;
+}
+
 KConfigGroup PanelView::panelConfig(ShellCorona *corona, Plasma::Containment *containment, QScreen *screen)
 {
     if (!containment || !screen) {
@@ -142,10 +188,10 @@ KConfigGroup PanelView::panelConfig(ShellCorona *corona, Plasma::Containment *co
     views = KConfigGroup(&views, QStringLiteral("Panel %1").arg(containment->id()));
 
     if (containment->formFactor() == Plasma::Types::Vertical) {
-        return KConfigGroup(&views, QStringLiteral("Vertical") + QString::number(screen->size().height()));
+        return KConfigGroup(&views, QString(u"Vertical" + QString::number(screen->size().height())));
         // treat everything else as horizontal
     } else {
-        return KConfigGroup(&views, QStringLiteral("Horizontal") + QString::number(screen->size().width()));
+        return KConfigGroup(&views, QString(u"Horizontal" + QString::number(screen->size().width())));
     }
 }
 
@@ -363,6 +409,7 @@ void PanelView::setFloating(bool floating)
         m_corona->requestApplicationConfigSync();
     }
     Q_EMIT floatingChanged();
+    Q_EMIT unsupportedConfigurationChanged();
 
     updateFloating();
     updateEnabledBorders();
@@ -379,6 +426,29 @@ int PanelView::minThickness() const
     return 0;
 }
 
+bool PanelView::isUnsupportedConfiguration() const
+{
+    return isUnsupportedEnvironment() && (floating() != defaultFloating() || opacityMode() != defaultOpacityMode());
+}
+
+QString PanelView::unsupportedConfigurationDescription() const
+{
+    if (isUnsupportedConfiguration()) {
+        return i18n(
+            "With an NVIDIA GPU on X11, the Floating style and Adaptive opacity mode are known to cause poor window drag and resize performance. Consider "
+            "using other settings.");
+    }
+    return QString();
+}
+
+void PanelView::fixUnsupportedConfiguration()
+{
+    if (isUnsupportedConfiguration()) {
+        setFloating(defaultFloating());
+        setOpacityMode(defaultOpacityMode());
+    }
+}
+
 QRect PanelView::relativeConfigRect() const
 {
     PanelConfigView *panelConfigView = qobject_cast<PanelConfigView *>(m_panelConfigView);
@@ -470,6 +540,7 @@ void PanelView::setOpacityMode(PanelView::OpacityMode mode)
             m_corona->requestApplicationConfigSync();
         }
         Q_EMIT opacityModeChanged();
+        Q_EMIT unsupportedConfigurationChanged();
     }
 }
 
@@ -528,23 +599,19 @@ void PanelView::updateLayerWindow()
     switch (containment()->location()) {
     case Plasma::Types::TopEdge:
         anchors.setFlag(LayerShellQt::Window::AnchorTop);
-        margins.setTop((-m_topFloatingPadding - m_bottomFloatingPadding) * (1 - m_floatingness));
         edge = LayerShellQt::Window::AnchorTop;
         break;
     case Plasma::Types::LeftEdge:
         anchors.setFlag(LayerShellQt::Window::AnchorLeft);
-        margins.setLeft((-m_rightFloatingPadding - m_leftFloatingPadding) * (1 - m_floatingness));
         edge = LayerShellQt::Window::AnchorLeft;
         break;
     case Plasma::Types::RightEdge:
         anchors.setFlag(LayerShellQt::Window::AnchorRight);
-        margins.setRight((-m_rightFloatingPadding - m_leftFloatingPadding) * (1 - m_floatingness));
         edge = LayerShellQt::Window::AnchorRight;
         break;
     case Plasma::Types::BottomEdge:
     default:
         anchors.setFlag(LayerShellQt::Window::AnchorBottom);
-        margins.setBottom((-m_topFloatingPadding - m_bottomFloatingPadding) * (1 - m_floatingness));
         edge = LayerShellQt::Window::AnchorBottom;
         break;
     }
@@ -648,6 +715,7 @@ void PanelView::positionAndResizePanel()
 
     updateLayerWindow();
     m_internalResize = true;
+
     setGeometry(geom);
     updateMask();
     Q_EMIT geometryChanged();
@@ -656,21 +724,16 @@ void PanelView::positionAndResizePanel()
     KWindowEffects::slideWindow(this, slideLocation(), -1);
 }
 
-QRect PanelView::geometryByDistance(int distance) const
-{
-    return geometryByDistance(distance, m_floatingness);
-}
-
 QRect PanelView::dogdeGeometryByDistance(int distance) const
 {
     if (!containment() || !m_screenToFollow) {
         return QRect();
     }
-    const QRect dodgeGeometry = geometryByDistance(distance, m_floating ? 1 : 0);
+    const QRect dodgeGeometry = geometryByDistance(distance);
     return dodgeGeometry & m_screenToFollow->geometry();
 }
 
-QRect PanelView::geometryByDistance(int distance, double floatingness) const
+QRect PanelView::geometryByDistance(int distance) const
 {
     if (!containment() || !m_screenToFollow) {
         return QRect();
@@ -713,20 +776,20 @@ QRect PanelView::geometryByDistance(int distance, double floatingness) const
 
     switch (containment()->location()) {
     case Plasma::Types::TopEdge:
-        r.moveTop(screenGeometry.top() + distance + (-m_topFloatingPadding - m_bottomFloatingPadding) * (1 - floatingness));
+        r.moveTop(screenGeometry.top() + distance);
         break;
 
     case Plasma::Types::LeftEdge:
-        r.moveLeft(screenGeometry.left() + distance + (-m_rightFloatingPadding - m_leftFloatingPadding) * (1 - floatingness));
+        r.moveLeft(screenGeometry.left() + distance);
         break;
 
     case Plasma::Types::RightEdge:
-        r.moveRight(screenGeometry.right() - distance - (-m_rightFloatingPadding - m_leftFloatingPadding) * (1 - floatingness));
+        r.moveRight(screenGeometry.right() - distance);
         break;
 
     case Plasma::Types::BottomEdge:
     default:
-        r.moveBottom(screenGeometry.bottom() - distance - (-m_topFloatingPadding - m_bottomFloatingPadding) * (1 - floatingness));
+        r.moveBottom(screenGeometry.bottom() - distance);
     }
     return r;
 }
@@ -799,14 +862,14 @@ void PanelView::restore()
     // but fallback on the screen independent section, as is the only place
     // is safe to directly write during plasma startup, as there can be
     // resolution changes
-    m_offset = readConfigValueWithFallBack("offset", m_offset);
+    m_offset = readConfigValueWithFallBack(u"offset"_s, m_offset);
     if (m_alignment == Qt::AlignCenter) {
         m_offset = 0;
     } else {
         m_offset = qMax(0, m_offset);
     }
 
-    setFloating((bool)config().parent().readEntry<int>("floating", true));
+    setFloating((bool)config().parent().readEntry<int>("floating", defaultFloating()));
     setThickness(configDefaults().readEntry("thickness", m_thickness));
 
     const QSize screenSize = m_screenToFollow->size();
@@ -815,15 +878,15 @@ void PanelView::restore()
 
     const int side = containment()->formFactor() == Plasma::Types::Vertical ? screenSize.height() : screenSize.width();
     const int maxSize = side - m_offset;
-    m_maxLength = qBound<int>(MINSIZE, readConfigValueWithFallBack("maxLength", side), maxSize);
-    m_minLength = qBound<int>(MINSIZE, readConfigValueWithFallBack("minLength", side), maxSize);
+    m_maxLength = qBound<int>(MINSIZE, readConfigValueWithFallBack(u"maxLength"_s, side), maxSize);
+    m_minLength = qBound<int>(MINSIZE, readConfigValueWithFallBack(u"minLength"_s, side), maxSize);
 
     // panelVisibility is not resolution dependent
     // but if fails read it from the resolution dependent one as
     // the place for this config key is changed in Plasma 5.9
     // Do NOT use readConfigValueWithFallBack
     setVisibilityMode((VisibilityMode)panelConfig.parent().readEntry<int>("panelVisibility", panelConfig.readEntry<int>("panelVisibility", (int)NormalPanel)));
-    setOpacityMode((OpacityMode)config().parent().readEntry<int>("panelOpacity", PanelView::OpacityMode::Adaptive));
+    setOpacityMode((OpacityMode)config().parent().readEntry<int>("panelOpacity", defaultOpacityMode()));
     setLengthMode((LengthMode)config().parent().readEntry<int>("panelLengthMode", PanelView::LengthMode::FillAvailable));
     positionAndResizePanel();
 
@@ -846,7 +909,14 @@ void PanelView::showConfigurationInterface(Plasma::Applet *applet)
     if (isPanelConfig) {
         if (m_panelConfigView && m_panelConfigView->isVisible()) {
             m_panelConfigView->hide();
-            cont->corona()->setEditMode(false);
+
+            // We only exit edit mode if there's no other containment
+            // being configured.
+
+            if (!m_corona->enteredEditModeViaDesktop()) {
+                m_corona->setEditMode(false);
+            }
+
         } else if (m_panelConfigView) {
             m_panelConfigView->show();
             m_panelConfigView->requestActivate();
@@ -879,6 +949,7 @@ void PanelView::showConfigurationInterface(Plasma::Applet *applet)
             updateEditModeLabel();
         }
     } else {
+        containment()->corona()->setEditMode(false);
         if (m_appletConfigView && m_appletConfigView->applet() == applet) {
             m_appletConfigView->show();
             m_appletConfigView->requestActivate();
@@ -1006,8 +1077,9 @@ void PanelView::integrateScreen()
     if (KWindowSystem::isPlatformX11()) {
         KX11Extras::setOnAllDesktops(winId(), true);
         KX11Extras::setType(winId(), NET::Dock);
-        // QXcbWindow isn't installed and thus inaccessible to us, but it does read this magic property...
-        setProperty("_q_xcb_wm_window_type", QNativeInterface::Private::QXcbWindow::Dock);
+        if (auto xcbWindow = nativeInterface<QNativeInterface::Private::QXcbWindow>()) {
+            xcbWindow->setWindowType(QNativeInterface::Private::QXcbWindow::Dock);
+        }
     }
 #endif
     setVisibilityMode(m_visibilityMode);
@@ -1020,7 +1092,7 @@ void PanelView::integrateScreen()
 void PanelView::updateEditModeLabel()
 {
     bool editMode = containment()->corona()->isEditMode();
-    QAction *action = containment()->internalAction("configure");
+    QAction *action = containment()->internalAction(u"configure"_s);
     if (!action) {
         return;
     }
@@ -1284,15 +1356,18 @@ QPointF PanelView::positionAdjustedForContainment(const QPointF &point) const
 
 void PanelView::updateMask()
 {
+    if (!containment()) {
+        return;
+    }
+
     if (m_backgroundHints == Plasma::Types::NoBackground) {
         KWindowEffects::enableBlurBehind(this, false);
         KWindowEffects::enableBackgroundContrast(this, false);
         setMask(QRegion());
     } else {
         QRegion mask;
-
         QQuickItem *rootObject = this->rootObject();
-        QRect screenPanelRect = geometry().intersected(screen()->geometry());
+        QRect screenPanelRect = geometry();
         screenPanelRect.moveTo(mapFromGlobal(screenPanelRect.topLeft()));
         if (rootObject) {
             QVariant maskProperty = rootObject->property("panelMask");
@@ -1317,6 +1392,24 @@ void PanelView::updateMask()
                                                  mask);
 
         if (!KWindowSystem::isPlatformX11() || KX11Extras::compositingActive()) {
+            const QRect bounding = mask.boundingRect();
+            // Always go to screen edge, to preserve fitts law
+            switch (containment()->location()) {
+            case Plasma::Types::LeftEdge:
+                screenPanelRect.setRight(bounding.right());
+                break;
+            case Plasma::Types::TopEdge:
+                screenPanelRect.setBottom(bounding.bottom());
+                break;
+            case Plasma::Types::RightEdge:
+                screenPanelRect.setLeft(bounding.left());
+                break;
+            case Plasma::Types::BottomEdge:
+                screenPanelRect.setTop(bounding.top());
+                break;
+            default:
+                break;
+            }
             setMask(screenPanelRect);
         } else {
             setMask(mask);
@@ -1413,7 +1506,16 @@ void PanelView::updateExclusiveZone()
         // overlap with the panel regardless of the visibility mode;
         // this won't be updated anymore as long as we are within
         // the panel configuration.
-        m_layerWindow->setExclusiveZone(thickness() - exclusiveMargin());
+        switch (containment()->formFactor()) {
+        case Plasma::Types::Horizontal:
+            m_layerWindow->setExclusiveZone(thickness() + m_topFloatingPadding + m_bottomFloatingPadding);
+            break;
+        case Plasma::Types::Vertical:
+            m_layerWindow->setExclusiveZone(thickness() + m_leftFloatingPadding + m_rightFloatingPadding);
+            break;
+        default:
+            qWarning() << "Warning: unexpected panel formFactor:" << containment()->formFactor() << "Horizontal or Vertical expected";
+        }
     }
     if (!containment() || containment()->isUserConfiguring() || !m_screenToFollow) {
         return;
@@ -1422,7 +1524,7 @@ void PanelView::updateExclusiveZone()
     if (KWindowSystem::isPlatformWayland()) {
         switch (m_visibilityMode) {
         case NormalPanel:
-            m_layerWindow->setExclusiveZone(thickness() - exclusiveMargin());
+            m_layerWindow->setExclusiveZone(thickness());
             break;
         case AutoHide:
         case DodgeWindows:
@@ -1587,9 +1689,15 @@ void PanelView::handleQmlStatusChange(QQmlComponent::Status status)
                 m_floatingness = get<double>(value);
                 positionAndResizePanel();
             });
+            connect(&m_floatingnessAnimation, &QPropertyAnimation::finished, rootObject, [this]() {
+                updateMask();
+            });
             connect(rootObject, SIGNAL(minPanelHeightChanged()), this, SLOT(updatePadding()));
             connect(rootObject, SIGNAL(minPanelWidthChanged()), this, SLOT(updatePadding()));
-            connect(rootObject, SIGNAL(hasShadowsChanged()), this, SLOT(updateShadows()));
+            connect(rootObject, SIGNAL(leftShadowMarginChanged()), this, SLOT(updateShadows()));
+            connect(rootObject, SIGNAL(topShadowMarginChanged()), this, SLOT(updateShadows()));
+            connect(rootObject, SIGNAL(rightShadowMarginChanged()), this, SLOT(updateShadows()));
+            connect(rootObject, SIGNAL(bottomShadowMarginChanged()), this, SLOT(updateShadows()));
             connect(rootObject, SIGNAL(floatingnessAnimationDurationChanged()), this, SLOT(updateFloatingAnimationDuration()));
             connect(rootObject, SIGNAL(floatingnessTargetChanged()), this, SLOT(updateFloating()));
         }
@@ -1692,38 +1800,48 @@ bool PanelView::edgeActivated() const
 
 void PanelView::updateEnabledBorders()
 {
+    if (!rootObject()) {
+        return;
+    }
     KSvg::FrameSvg::EnabledBorders borders = KSvg::FrameSvg::AllBorders;
     if (m_backgroundHints == Plasma::Types::NoBackground) {
         borders = KSvg::FrameSvg::NoBorder;
     } else {
-        switch (location()) {
-        case Plasma::Types::TopEdge:
-            borders &= ~KSvg::FrameSvg::TopBorder;
-            break;
-        case Plasma::Types::LeftEdge:
-            borders &= ~KSvg::FrameSvg::LeftBorder;
-            break;
-        case Plasma::Types::RightEdge:
-            borders &= ~KSvg::FrameSvg::RightBorder;
-            break;
-        case Plasma::Types::BottomEdge:
-            borders &= ~KSvg::FrameSvg::BottomBorder;
-            break;
-        default:
-            break;
+        if (m_floatingness == 0) {
+            switch (location()) {
+            case Plasma::Types::TopEdge:
+                borders &= ~KSvg::FrameSvg::TopBorder;
+                break;
+            case Plasma::Types::LeftEdge:
+                borders &= ~KSvg::FrameSvg::LeftBorder;
+                break;
+            case Plasma::Types::RightEdge:
+                borders &= ~KSvg::FrameSvg::RightBorder;
+                break;
+            case Plasma::Types::BottomEdge:
+                borders &= ~KSvg::FrameSvg::BottomBorder;
+                break;
+            default:
+                break;
+            }
         }
 
+        QMargins shadowPadding = {int(std::round(rootObject()->property("leftShadowMargin").toReal())),
+                                  int(std::round(rootObject()->property("topShadowMargin").toReal())),
+                                  int(std::round(rootObject()->property("rightShadowMargin").toReal())),
+                                  int(std::round(rootObject()->property("bottomShadowMargin").toReal()))};
+
         if (m_screenToFollow) {
-            if (x() <= m_screenToFollow->geometry().x()) {
+            if (x() - shadowPadding.left() <= m_screenToFollow->geometry().x()) {
                 borders &= ~KSvg::FrameSvg::LeftBorder;
             }
-            if (x() + width() >= m_screenToFollow->geometry().x() + m_screenToFollow->geometry().width()) {
+            if (x() + width() + shadowPadding.right() >= m_screenToFollow->geometry().x() + m_screenToFollow->geometry().width()) {
                 borders &= ~KSvg::FrameSvg::RightBorder;
             }
-            if (y() <= m_screenToFollow->geometry().y()) {
+            if (y() - shadowPadding.top() <= m_screenToFollow->geometry().y()) {
                 borders &= ~KSvg::FrameSvg::TopBorder;
             }
-            if (y() + height() >= m_screenToFollow->geometry().y() + m_screenToFollow->geometry().height()) {
+            if (y() + height() + shadowPadding.bottom() >= m_screenToFollow->geometry().y() + m_screenToFollow->geometry().height()) {
                 borders &= ~KSvg::FrameSvg::BottomBorder;
             }
         }
@@ -1755,12 +1873,13 @@ void PanelView::updateShadows()
     if (!rootObject()) {
         return;
     }
-    bool hasShadows = rootObject()->property("hasShadows").toBool();
-    if (hasShadows) {
-        PanelShadows::self()->addWindow(this, enabledBorders());
-    } else {
-        PanelShadows::self()->removeWindow(this);
-    }
+    updateEnabledBorders();
+
+    QMargins extraShadowPadding = {int(std::round(rootObject()->property("leftShadowMargin").toReal())),
+                                   int(std::round(rootObject()->property("topShadowMargin").toReal())),
+                                   int(std::round(rootObject()->property("rightShadowMargin").toReal())),
+                                   int(std::round(rootObject()->property("bottomShadowMargin").toReal()))};
+    PanelShadows::self()->addWindow(this, enabledBorders(), extraShadowPadding);
 }
 
 void PanelView::updateFloating()
